@@ -43,21 +43,8 @@ $fieldset_label = ($allow_tags == "yes") ? "Tags" : "";
 $fieldset_label = ($allow_badges == "yes") ? "Badges" : $fieldset_label;
 $fieldset_label = ($allow_tags == "yes" && $allow_badges == "yes") ? "Tags and Badges" : $fieldset_label;
 
-$t = array();
-$b = array();
 
-foreach ($this->tags as $tag)
-{
-	$t[] = $tag['raw_tag'];
-}
 
-foreach ($this->badges as $badge)
-{
-	$b[] = $badge['raw_tag'];
-}
-
-$tags_list   = Event::trigger('hubzero.onGetMultiEntry', array(array('tags', 'tags', 'actags','', implode(",",$t))));
-$badges_list = Event::trigger('hubzero.onGetMultiEntry', array(array('tags', 'badges', 'actags1','', implode(",",$b))));
 
 //get the referrer
 $backLink = Route::url('index.php?option=' . $this->option);
@@ -161,12 +148,29 @@ $pid = Request::getInt('publication', 0);
 					</label>
 				</div>
 			</div>
+			<fieldset class="author-manager" data-add="<?php echo Route::url('index.php?option=com_citations&controller=authors&citation=' . $this->row->id . '&task=add&' . $this->token . '=1'); ?>" data-update="<?php echo Route::url('index.php?option=com_citations&controller=authors&citation=' . $this->row->id . '&task=update&' . $this->token . '=1'); ?>" data-list="<?php echo Route::url('index.php?option=com_citations&controller=authors&citation=' . $this->row->id . '&task=display&' . $this->token . '=1'); ?>">
+					<div class="grid">
+						<div class="col span10">
+							<label for="field-author">
+								<?php echo Lang::txt('COM_CITATIONS_AUTHORS') . ' '; ?>
+								<span class="required"><?php echo Lang::txt('JREQUIRED'); ?></span>
+								<?php
+									$mc = Event::trigger('hubzero.onGetMultiEntry', array(array('members', 'author', 'field-author', '', (isset($this->authorString) ? $this->authorString : ''))));
+									if (count($mc) > 0) {
+										echo $mc[0];
+									} else { ?>
+									<input type="text" name="author" id="field-author" value="" />
+								<?php } ?>
+							</label>
+						</div>
+						<div class="col span2 omega">
+							<button class="btn btn-success add-author"><?php echo Lang::txt('COM_CITATIONS_ADD'); ?></button>
+						</div>
+					</div>
 
-			<label for="author">
-				<?php echo Lang::txt('COM_CITATIONS_AUTHORS'); ?>:
-				<input type="text" name="fields[author]" id="author" size="30" value="<?php echo $this->escape($this->row->author); ?>" />
-				<span class="hint"><?php echo Lang::txt('COM_CITATIONS_AUTHORS_HINT'); ?></span>
-			</label>
+					<div class="field-wrap author-list">
+						<?php echo $this->setName('authors')->setLayout('display')->loadTemplate('authors'); ?>
+					</fieldset>
 
 			<label for="authoraddress">
 				<?php echo Lang::txt('COM_CITATIONS_AUTHOR_ADDRESS'); ?>:
@@ -350,7 +354,7 @@ $pid = Request::getInt('publication', 0);
 			</label>
 			<label for="formatted">
 				<?php echo Lang::txt('COM_CITATIONS_MANUALLY_FORMAT_CITATION'); ?>:
-				<textarea name="fields[formatted]" id="formatted" rows="8" cols="10"><?php echo $this->escape(stripslashes($this->row->formatted)); ?></textarea>
+				<textarea name="fields[formatted]" id="formatted" rows="8" cols="10"><?php echo $this->escape(stripslashes($this->row->get('formatted'))); ?></textarea>
 			</label>
 		</fieldset><div class="clear"></div>
 
@@ -361,6 +365,14 @@ $pid = Request::getInt('publication', 0);
 					<label>
 						<?php echo Lang::txt('COM_CITATIONS_TAGS'); ?>:
 						<?php
+							$tags_list = Event::trigger('hubzero.onGetMultiEntry', 
+												array(
+													array('tags', 'tags', 'actags', '', 
+														implode(",", $this->tags)
+													)	
+												)
+											);
+
 							if (count($tags_list) > 0) {
 								echo $tags_list[0];
 							} else {
@@ -375,6 +387,13 @@ $pid = Request::getInt('publication', 0);
 					<label class="badges">
 						<?php echo Lang::txt('COM_CITATIONS_BADGES'); ?>:
 						<?php
+							$badges_list = Event::trigger('hubzero.onGetMultiEntry', 
+												array(
+													array('tags', 'badges', 'actags1', '', 
+														implode(",", $this->badges)
+													)
+												)
+											);
 							if (count($badges_list) > 0) {
 								echo $badges_list[0];
 							} else {
@@ -404,7 +423,7 @@ $pid = Request::getInt('publication', 0);
 							<tr>
 								<th><?php echo Lang::txt('COM_CITATIONS_TYPE'); ?></th>
 								<th><?php echo Lang::txt('COM_CITATIONS_ID'); ?></th>
-								<!--<th><?php //echo Lang::txt('TABLE'); ?></th>-->
+								<th><?php echo Lang::txt('COM_CITATIONS_CONTEXT'); ?></th>
 							</tr>
 						</thead>
 						<tfoot>
@@ -425,11 +444,11 @@ $pid = Request::getInt('publication', 0);
 									if ($r == 0 || !isset($this->assocs[$i]))
 									{
 										$this->assocs[$i] = new stdClass;
-										$this->assocs[$i]->id   = NULL;
-										$this->assocs[$i]->cid  = NULL;
-										$this->assocs[$i]->oid  = NULL;
-										$this->assocs[$i]->type = NULL;
-										$this->assocs[$i]->tbl  = NULL;
+										$this->assocs[$i]->id   = null;
+										$this->assocs[$i]->cid  = $this->row->id;
+										$this->assocs[$i]->oid  = null;
+										$this->assocs[$i]->type = null;
+										$this->assocs[$i]->tbl  = null;
 									}
 
 									echo "\t\t\t".'  <tr>'."\n";
@@ -447,6 +466,17 @@ $pid = Request::getInt('publication', 0);
 									echo "\t\t\t".'<td><input type="text" name="assocs['.$i.'][oid]" value="'.$this->assocs[$i]->oid.'" />'."\n";
 									echo "\t\t\t\t".'<input type="hidden" name="assocs['.$i.'][id]" value="'.$this->assocs[$i]->id.'" />'."\n";
 									echo "\t\t\t\t".'<input type="hidden" name="assocs['.$i.'][cid]" value="'.$this->assocs[$i]->cid.'" /></td>'."\n";
+									echo "\t\t\t".'<td><select name="assocs['.$i.'][type]">'."\n";
+									echo ' <option value=""';
+									echo ($this->assocs[$i]->type == '') ? ' selected="selected"': '';
+									echo '>'.Lang::txt('COM_CITATIONS_SELECT').'</option>'."\n";
+									echo ' <option value="references"';
+									echo ($this->assocs[$i]->type == 'references') ? ' selected="selected"': '';
+									echo '>'.Lang::txt('COM_CITATIONS_CONTEXT_REFERENCES').'</option>'."\n";
+									echo ' <option value="referencedby"';
+									echo ($this->assocs[$i]->type == 'referencedby') ? ' selected="selected"': '';
+									echo '>'.Lang::txt('COM_CITATIONS_CONTEXT_REFERENCEDBY').'</option>'."\n";
+									echo '</select></td>'."\n";
 									echo "\t\t\t".'</tr>'."\n";
 								}
 						?>
@@ -490,4 +520,4 @@ $pid = Request::getInt('publication', 0);
 			</a>
 		</p>
 	</form>
-</section>
\ No newline at end of file
+</section>
