@@ -455,7 +455,7 @@ class Manage extends AdminController
 	 */
 	private function _handleSuperGroup($group)
 	{
-		//get the upload path for groups
+		// get the upload path for groups
 		$uploadPath = PATH_APP . DS . trim($this->config->get('uploadpath', '/site/groups'), DS) . DS . $group->get('gidNumber');
 
 		// get the source path
@@ -547,14 +547,14 @@ class Manage extends AdminController
 		}
 		else
 		{
-			Notify::error(Lang::txt('COM_GROUPS_SUPER_UNABLE_TO_CREATE_DB'));
+			Notify::warning(Lang::txt('COM_GROUPS_SUPER_UNABLE_TO_CREATE_DB'));
 		}
 
 		// check to see if we have a super group db config
 		$supergroupDbConfigFile = DS . 'etc' . DS . 'supergroup.conf';
 		if (!file_exists($supergroupDbConfigFile))
 		{
-			Notify::error(Lang::txt('COM_GROUPS_SUPER_UNABLE_TO_LOAD_CONFIG'));
+			Notify::warning(Lang::txt('COM_GROUPS_SUPER_UNABLE_TO_LOAD_CONFIG'));
 		}
 		else
 		{
@@ -695,7 +695,7 @@ class Manage extends AdminController
 		}
 
 		// build command to run via shell
-		// this will init the git repo, make the inital commit and push to the repo management machine
+		// this will init the git repo, make the initial commit and push to the repo management machine
 		$cmd  = 'sh ' . dirname(dirname(__DIR__)) . DS . 'admin' . DS . 'assets' . DS . 'scripts' . DS . 'gitlab_setup.sh ';
 		$cmd .= $uploadPath  . ' ' . $authorInfo . ' ' . $gitLabProject['ssh_url_to_repo'] . ' 2>&1';
 
@@ -739,10 +739,7 @@ class Manage extends AdminController
 		// empty list?
 		if (empty($ids))
 		{
-			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-			);
-			return;
+			return $this->cancelTask();
 		}
 
 		// vars to hold results of pull
@@ -861,11 +858,12 @@ class Manage extends AdminController
 		}
 
 		// display view
-		$this->view->setLayout('fetched');
-		$this->view->success = $success;
-		$this->view->failed  = $failed;
-		$this->view->config  = $this->config;
-		$this->view->display();
+		$this->view
+			->set('success', $success)
+			->set('failed', $failed)
+			->set('config', $this->config)
+			->setLayout('fetched')
+			->display();
 	}
 
 	/**
@@ -936,7 +934,6 @@ class Manage extends AdminController
 				}
 			}
 
-
 			// build command to run via shell
 			$cmd = "cd {$uploadPath} && ";
 
@@ -1205,7 +1202,10 @@ class Manage extends AdminController
 		// Check for request forgeries
 		Request::checkToken(['get', 'post']);
 
-		if (!User::authorise('core.edit.state', $this->_option))
+		if (!User::authorise('core.manage', $this->_option)
+		 && !User::authorise('core.admin', $this->_option)
+		 && !User::authorise('core.edit', $this->_option)
+		 && !User::authorise('core.edit.state', $this->_option))
 		{
 			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
 		}
@@ -1271,7 +1271,10 @@ class Manage extends AdminController
 		// Check for request forgeries
 		Request::checkToken(['get', 'post']);
 
-		if (!User::authorise('core.edit.state', $this->_option))
+		if (!User::authorise('core.manage', $this->_option)
+		 && !User::authorise('core.admin', $this->_option)
+		 && !User::authorise('core.edit', $this->_option)
+		 && !User::authorise('core.edit.state', $this->_option))
 		{
 			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
 		}
@@ -1380,12 +1383,7 @@ class Manage extends AdminController
 		// can user perform task
 		if (!$canDo->get($taskName) || (!$canDo->get('core.admin') && $task == 'edit' && $group->get('type') == 0))
 		{
-			// No access - redirect to main listing
-			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-				Lang::txt('COM_GROUPS_NOT_AUTH'),
-				'error'
-			);
+			// No access
 			return false;
 		}
 
