@@ -462,7 +462,7 @@ class Record extends \Hubzero\Content\Import\Model\Record
 					}
 				}
 
-				// Try to create from portion preceeding @ in email address
+				// Try to create from portion preceding @ in email address
 				if (!$valid)
 				{
 					$username = strstr($this->record->entry->get('email'), '@', true);
@@ -593,7 +593,7 @@ class Record extends \Hubzero\Content\Import\Model\Record
 		if ($isNew && $this->_options['emailnew'] == 1)
 		{
 			$eview = new \Hubzero\Component\View(array(
-				'base_path' => PATH_CORE . DS . 'components' . DS . 'com_members' . DS . 'site',
+				'base_path' => dirname(dirname(__DIR__)) . DS . 'site',
 				'name'      => 'emails',
 				'layout'    => 'confirm'
 			));
