@@ -757,7 +757,7 @@ class Profiles extends SiteController
 		{
 			App::redirect(
 				Route::url('index.php?option=com_users&view=login&return=' . base64_encode(Route::url('index.php?option=' . $this->_option . '&task=myaccount', false, true)), false),
-				Lang::txt('You must be logged in to access this area.'),
+				Lang::txt('COM_MEMBERS_NOT_LOGGEDIN'),
 				'warning'
 			);
 		}
@@ -776,7 +776,7 @@ class Profiles extends SiteController
 	{
 		// Incoming
 		$id  = Request::getVar('id', 0);
-		$tab = Request::getVar('active', 'dashboard');  // The active tab (section)
+		$tab = Request::getVar('active');  // The active tab (section)
 
 		// Get the member's info
 		if (is_numeric($id))
@@ -835,7 +835,7 @@ class Profiles extends SiteController
 		{
 			App::abort(404, Lang::txt('COM_MEMBERS_NOT_FOUND'));
 
-			// Offer explaination and eternal redemption to the user, instead of leaving them high and dry
+			// Offer explanation and eternal redemption to the user, instead of leaving them high and dry
 			/*
 			$this->view
 				->set('title', Lang::txt('COM_MEMBERS_REGISTER_UNCONFIRMED'))
@@ -875,10 +875,9 @@ class Profiles extends SiteController
 			}
 		}
 
-		//if ($tab != 'profile' && !in_array($tab, $available))
+		// If no active tab specified, default to the first available
 		if (!in_array($tab, $available) && isset($available[0]))
 		{
-			//$tab = 'profile';
 			$tab = $available[0];
 		}
 
@@ -904,6 +903,17 @@ class Profiles extends SiteController
 			stripslashes($profile->get('name')),
 			'index.php?option=' . $this->_option . '&id=' . $profile->get('id')
 		);
+		foreach ($cats as $k => $c)
+		{
+			if ($tab == key($c))
+			{
+				Pathway::append(
+					$c[$tab],
+					'index.php?option=' . $this->_option . '&id=' . $profile->get('id') . '&active=' . $tab
+				);
+				break;
+			}
+		}
 
 		// Output HTML
 		$this->view
@@ -1044,7 +1054,12 @@ class Profiles extends SiteController
 
 		$passrules = false;
 
-		if (!\Hubzero\User\Password::passwordMatches($profile->get('id'), $oldpass, true))
+		// Check if they have a previously set pass
+		// If not, then they created an account via a 3rd-party
+		// authenticator and are setting a new local password
+		$hzup = \Hubzero\User\Password::getInstance($profile->get('id'));
+
+		if (($hzup && !empty($hzup->passhash)) && !\Hubzero\User\Password::passwordMatches($profile->get('id'), $oldpass, true))
 		{
 			$this->setError(Lang::txt('COM_MEMBERS_PASS_INCORRECT'));
 		}
@@ -1056,7 +1071,7 @@ class Profiles extends SiteController
 		{
 			$this->setError(Lang::txt('COM_MEMBERS_PASS_NEW_CONFIRMATION_MISMATCH'));
 		}
-		elseif ($oldpass == $newpass)
+		elseif (($hzup && !empty($hzup->passhash)) && $oldpass == $newpass)
 		{
 			// make sure the current password and new password are not the same
 			// this should really be done in the password rules validation step
@@ -1212,7 +1227,7 @@ class Profiles extends SiteController
 			switch ($k)
 			{
 				case 'sessions':
-					include_once(PATH_CORE . DS . 'components' . DS . 'com_tools' . DS . 'tables' . DS . 'preferences.php');
+					include_once Component::path('com_tools') . DS . 'tables' . DS . 'preferences.php';
 
 					$preferences = new \Components\Tools\Tables\Preferences($this->database);
 					$preferences->loadByUser($profile->get('id'));
@@ -1469,7 +1484,7 @@ class Profiles extends SiteController
 			->ordered()
 			->rows();
 
-		// Ouput HTML
+		// Output HTML
 		$this->view
 			->set('title', $title)
 			->set('profile', $profile)
