@@ -32,12 +32,14 @@
 
 namespace Components\Projects\Models\Adapters;
 
-use Hubzero\Base\Object;
 use Components\Projects\Models;
 use Components\Projects\Helpers;
+use Component;
+use Filesystem;
+use Lang;
 
 // Get git helper
-require_once PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'helpers' . DS . 'githelper.php';
+require_once dirname(dirname(__DIR__)) . DS . 'helpers' . DS . 'githelper.php';
 
 /**
  * Projects Git adapter class
@@ -91,7 +93,8 @@ class Git extends Models\Adapter
 	public function count($params = array())
 	{
 		$cmd  = 'cd ' . escapeshellarg($this->_path) . ' && ';
-		$cmd .='find . \( -path "./.git" -or -name ".gitignore" \) -prune -o -type f -print | wc -l';
+		$cmd .='find . \( -path ./.git -o -name ".gitignore" \) -prune -o -type f -print | wc -l';
+
 		return shell_exec($cmd);
 	}
 
@@ -173,7 +176,6 @@ class Git extends Models\Adapter
 			// Load basic file metadata
 			$file = new Models\File($item, $this->_path);
 
-
 			// Untracked?
 			if (in_array($file->get('localPath'), $untracked))
 			{
@@ -224,7 +226,8 @@ class Git extends Models\Adapter
 					break;
 
 					case 'modified':
-						$sorting[] = $file->get('date');
+						// Need to get extra metadata (slower)
+						$sorting[] = $this->_file($file, $dirPath, 'date');
 					break;
 
 					case 'localpath':
@@ -821,13 +824,12 @@ class Git extends Models\Adapter
 				return 0;
 			}
 
-			exec('du -sk ' . $where, $out);
+			exec('du -sb --exclude=.git ' . $where, $out);
 
 			if ($out && isset($out[0]))
 			{
 				$dir = $git == true ? '.git' : '.';
-				$kb = str_replace($dir, '', trim($out[0]));
-				$used = $kb * 1024;
+				$used = str_replace($dir, '', trim($out[0]));
 			}
 		}
 
