@@ -32,20 +32,26 @@
 
 namespace Components\Projects\Models;
 
-use Hubzero\Base\Object;
+use Hubzero\Base\Obj;
 use Components\Projects\Tables;
 use Components\Projects\Helpers;
 use Components\Projects\Models;
+use Filesystem;
+use Exception;
+use Request;
+use Plugin;
+use Lang;
 
 require_once(dirname(__DIR__) . DS . 'tables' . DS . 'repo.php');
 require_once(dirname(__DIR__) . DS . 'helpers' . DS . 'githelper.php');
+require_once(dirname(__DIR__) . DS . 'helpers' . DS . 'nogithelper.php');
 require_once(__DIR__ . DS . 'file.php');
 require_once(__DIR__ . DS . 'adapter.php');
 
 /**
  * Project Repository model
  */
-class Repo extends Object
+class Repo extends Obj
 {
 	/**
 	 * Tables\Repo
@@ -55,7 +61,7 @@ class Repo extends Object
 	private $_tbl = null;
 
 	/**
-	 * \JDatabase
+	 * Database
 	 *
 	 * @var  object
 	 */
@@ -77,8 +83,8 @@ class Repo extends Object
 
 	/**
 	 * Constructor
-	 * @param    object   $project Project model
-	 *
+	 * @param   object  $project  Project model
+	 * @param   string  $name
 	 * @return  void
 	 */
 	public function __construct($project = null, $name = 'local')
@@ -124,17 +130,35 @@ class Repo extends Object
 		}
 		else
 		{
-			$helper = new Helpers\Git(Helpers\Html::getProjectRepoPath(
-				$this->get('project')->get('alias')));
-			$gitInitCheck = $helper->callGit('status');
-			if (is_array($gitInitCheck) && in_array('# Changes to be committed:', $gitInitCheck))
+			// Use regex to avoid what might be a caching thing with Tables
+			$matches = array();
+			preg_match('/versionTracking=(\d)/', $this->get('project')->get('params'), $matches);
+			// Only use git adapter if project specifies it - otherwise assume we're not using git
+			if (isset($matches[1]) && $matches[1] == 1)
 			{
-				$helper->callGit('commit -am "Initial commit"');
+				$engine = 'git';
+			}
+			else
+			{
+				$engine = 'nogit';
+			}
+
+			$cls = "Helpers\\" . ucfirst($engine);
+			if ($engine == 'git')
+			{
+				$helper = new Helpers\Git(Helpers\Html::getProjectRepoPath(
+					$this->get('project')->get('alias')));
+				$helper->iniGit();
+			}
+			else
+			{
+				$helper = new Helpers\Nogit(Helpers\Html::getProjectRepoPath(
+					$this->get('project')->get('alias')));
 			}
 
 			// Local Git repo  (/files)
 			$this->set('project_id', $this->get('project')->get('id'));
-			$this->set('engine', 'git');
+			$this->set('engine', $engine);
 			$this->set('remote', 0);
 			$this->set('status', 1);
 			$this->set('path', Helpers\Html::getProjectRepoPath(
@@ -154,7 +178,23 @@ class Repo extends Object
 	{
 		if (!$this->_adapter)
 		{
-			$engine = strtolower($this->get('engine', 'git'));
+			$engine = 'nogit';
+
+			if (is_object($this->get('project')))
+			{
+				// Use regex to avoid what might be a caching thing with Tables
+				$matches = array();
+				preg_match('/versionTracking=(\d)/', $this->get('project')->get('params'), $matches);
+				// Only use git adapter if project specifies it - otherwise assume we're not using git
+				if (isset($matches[1]) && $matches[1] == 1)
+				{
+					$engine = 'git';
+				}
+				else
+				{
+					$engine = 'nogit';
+				}
+			}
 
 			$cls = __NAMESPACE__ . '\\Adapters\\' . ucfirst($engine);
 
@@ -174,6 +214,18 @@ class Repo extends Object
 		return $this->_adapter;
 	}
 
+	public function getAdapterName()
+	{
+		if (!$this->_adapter)
+		{
+			$this->_adapter();
+		}
+		$class = get_class($this->_adapter);
+		$lastSlash = strrpos($class, '\\');
+		$className = substr($class, $lastSlash + 1);
+		return strtolower($className);
+	}
+
 	/**
 	 * Check that repo exists and connection established
 	 *
@@ -479,15 +531,15 @@ class Repo extends Object
 		// Check that we directory name is not reserved for other purposes
 		if (dirname($localDirPath) == '.' && in_array(strtolower($newDir), $reserved))
 		{
-			$this->setError( Lang::txt('COM_PROJECTS_FILES_ERROR_DIR_RESERVED_NAME') );
+			$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_DIR_RESERVED_NAME'));
 			return false;
 		}
 
 		// Directory already exists ?
 		if ($this->dirExists($localDirPath))
 		{
-			$this->setError( Lang::txt('COM_PROJECTS_FILES_ERROR_DIR_CREATE') . ' "' . $newDir . '". '
-			. Lang::txt('COM_PROJECTS_FILES_ERROR_DIRECTORY_EXISTS') );
+			$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_DIR_CREATE') . ' "' . $newDir . '". '
+			. Lang::txt('COM_PROJECTS_FILES_ERROR_DIRECTORY_EXISTS'));
 			return false;
 		}
 
@@ -503,7 +555,7 @@ class Repo extends Object
 		else
 		{
 			// Failed to create directory
-			$this->setError( Lang::txt('COM_PROJECTS_FILES_ERROR_DIR_CREATE') );
+			$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_DIR_CREATE'));
 			return false;
 		}
 	}
@@ -855,7 +907,7 @@ class Repo extends Object
 		else
 		{
 			// Failed
-			$this->setError( Lang::txt('COM_PROJECTS_FILES_ERROR_RENAME') );
+			$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_RENAME'));
 			return false;
 		}
 	}
@@ -863,6 +915,7 @@ class Repo extends Object
 	/**
 	 * Update file in the repo
 	 *
+	 * @param   array    $params
 	 * @return  boolean
 	 */
 	public function update($params = array())
@@ -875,6 +928,7 @@ class Repo extends Object
 	/**
 	 * Insert file into the repo
 	 *
+	 * @param   array    $params
 	 * @return  boolean
 	 */
 	public function insert($params = array())
@@ -964,7 +1018,7 @@ class Repo extends Object
 		else
 		{
 			// Regular upload
-			$upload = Request::getVar( 'upload', '', 'files', 'array' );
+			$upload = Request::getVar('upload', '', 'files', 'array');
 
 			if (empty($upload['name']) or $upload['name'][0] == '')
 			{
@@ -1120,7 +1174,7 @@ class Repo extends Object
 		// Success - check in change
 		$this->call('checkin', $params);
 
-		return array('localPath' => $localPath, 'replace' => $exists );
+		return array('localPath' => $localPath, 'replace' => $exists);
 	}
 
 	/**
@@ -1179,7 +1233,7 @@ class Repo extends Object
 			$this->call('checkin', $params);
 		}
 
-		return array('localPath' => $localPath, 'replace' => $exists );
+		return array('localPath' => $localPath, 'replace' => $exists);
 	}
 
 	/**
@@ -1219,7 +1273,7 @@ class Repo extends Object
 			try
 			{
 				chdir($tempPath);
-				exec('tar zxvf ' . $tmp_name . ' -C ' . $extractPath . ' 2>&1', $out );
+				exec('tar zxvf ' . $tmp_name . ' -C ' . $extractPath . ' 2>&1', $out);
 			}
 			catch (Exception $e)
 			{
@@ -1269,9 +1323,9 @@ class Repo extends Object
 		$dirPath   = isset($params['subdir']) ? $params['subdir'] : null;
 
 		$extracted = Filesystem::files($extractPath, '.', true, true,
-			$exclude = array('.svn', 'CVS', '.DS_Store', '__MACOSX' ));
+			$exclude = array('.svn', 'CVS', '.DS_Store', '__MACOSX'));
 
-		// check for viruses - scans the directory for efficency
+		// check for viruses - scans the directory for efficiency
 		$command = "clamscan -i --no-summary --block-encrypted -r " . $extractPath;
 		exec($command, $output, $virus_status);
 		$virusChecked = false;
@@ -1333,9 +1387,9 @@ class Repo extends Object
 			$exists = is_file($where) ? true : false;
 
 			// Provision directory
-			if ($safe_dir && !$skipDir && !is_dir($target . DS . $safe_dir ))
+			if ($safe_dir && !$skipDir && !is_dir($target . DS . $safe_dir))
 			{
-				if (Filesystem::makeDirectory( $target . DS . $safe_dir, 0755, true, true ))
+				if (Filesystem::makeDirectory($target . DS . $safe_dir, 0755, true, true))
 				{
 					// File object
 					$localDirPath = $dirPath ? $dirPath . DS . $safe_dir : $safe_dir;
@@ -1384,16 +1438,16 @@ class Repo extends Object
 	{
 		if (!isset($this->_sizeLimit))
 		{
-			$pParams = Plugin::params( 'projects', 'files' );
+			$pParams = Plugin::params('projects', 'files');
 			$this->_sizeLimit = $pParams->get('maxUpload', '104857600');
 		}
 
 		// Check against upload size limit
 		if (intval($this->_sizeLimit) && $size > intval($this->_sizeLimit))
 		{
-			$this->setError( Lang::txt('COM_PROJECTS_FILES_ERROR_EXCEEDS_LIMIT') . ' '
+			$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_EXCEEDS_LIMIT') . ' '
 				. \Hubzero\Utility\Number::formatBytes($this->_sizeLimit) . '. '
-				. Lang::txt('COM_PROJECTS_FILES_ERROR_TOO_LARGE_USE_OTHER_METHOD') );
+				. Lang::txt('COM_PROJECTS_FILES_ERROR_TOO_LARGE_USE_OTHER_METHOD'));
 			return false;
 		}
 
@@ -1409,8 +1463,8 @@ class Repo extends Object
 		{
 			if (Helpers\Html::virusCheck($tmp_name))
 			{
-					$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_VIRUS'));
-					return false;
+				$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_VIRUS'));
+				return false;
 			}
 		}
 
@@ -1431,7 +1485,7 @@ class Repo extends Object
 		{
 			if (!Filesystem::makeDirectory($this->get('path'), 0755, true, true))
 			{
-				$this->setError( Lang::txt('COM_PROJECTS_FILES_ERROR_UNABLE_TO_CREATE_PATH') );
+				$this->setError(Lang::txt('COM_PROJECTS_FILES_ERROR_UNABLE_TO_CREATE_PATH'));
 				return false;
 			}
 		}
@@ -1456,10 +1510,9 @@ class Repo extends Object
 	/**
 	 * Get files stats for all projects
 	 *
-	 * @param      array	$aliases	Project aliases for which to compute stats
-	 * @param      string		$get
-	 *
-	 * @return     mixed
+	 * @param   array   $aliases  Project aliases for which to compute stats
+	 * @param   string  $get
+	 * @return  mixed
 	 */
 	public function getStats($aliases = array(), $get = 'total')
 	{
@@ -1477,17 +1530,16 @@ class Repo extends Object
 		if ($get == 'pubspace')
 		{
 			// Load publications component configs
-			$pubconfig = Component::params( 'com_publications' );
+			$pubconfig = Component::params('com_publications');
 			$base_path = DS . trim($pubconfig->get('webpath'), DS);
 
 			chdir(PATH_APP . $base_path);
-			exec('du -sk ', $out);
+			exec('du -sb ', $out);
 			$used = 0;
 
 			if ($out && isset($out[0]))
 			{
-				$kb = str_replace('.', '', trim($out[0]));
-				$used = $kb * 1024;
+				$used = str_replace('.', '', trim($out[0]));
 			}
 
 			return $used;
@@ -1516,30 +1568,48 @@ class Repo extends Object
 			}
 			else
 			{
-				$git = new Helpers\Git($path);
-				if ($get == 'commitCount')
+				$engine = 'nogit';
+				if ($this->get('project'))
 				{
-					$nf = $git->callGit('ls-files --full-name ');
-
-					if ($nf && substr($nf[0], 0, 5) != 'fatal')
+					$engine = $this->get('project')->params->get('engine', 'nogit');
+				}
+				if ($engine == 'git')
+				{
+					$git = new Helpers\Git($path);
+					if ($get == 'commitCount')
 					{
-						$out = $git->callGit('log | grep "^commit" | wc -l' );
-
-						if (is_array($out))
+						$nf = $git->callGit('ls-files --full-name ');
+						if ($nf && substr($nf[0], 0, 5) != 'fatal')
 						{
-							$c =  end($out);
-							$commits = $commits + $c;
+							$out = $git->callGit('log | grep "^commit" | wc -l');
+							if (is_array($out))
+							{
+								$c =  end($out);
+								$commits = $commits + $c;
+							}
+						}
+					}
+					else
+					{
+						$count = count($git->getFiles());
+						$files = $files + $count;
+						if ($count > 1)
+						{
+							$usage++;
 						}
 					}
 				}
 				else
 				{
-					$count = count($git->getFiles());
-					$files = $files + $count;
-
+					$commits = 0; // There are no commits in nogit, stub for reports
+					$helper = new Helpers\Nogit($path);
+					$recursive = true;
+					$subdir = '';
+					$count = count($helper->getFiles($subdir, $recursive));
+					$files = $files + $count; // Count the files in a project and add to total for a report
 					if ($count > 1)
 					{
-						$usage++;
+						$usage++; // A project is using files, increment for reports
 					}
 				}
 			}
@@ -1566,10 +1636,10 @@ class Repo extends Object
 	/**
 	 * Parse status for each file revision
 	 *
-	 * @param      array	$versions	Array of file version data
-	 * @return     array
+	 * @param   array  $versions  Array of file version data
+	 * @return  array
 	 */
-	protected function _getVersionStatus( $versions = array())
+	protected function _getVersionStatus($versions = array())
 	{
 		if (count($versions) == 0)
 		{
@@ -1579,9 +1649,9 @@ class Repo extends Object
 		// Go through versions in reverse (from oldest to newest)
 		for ($k = (count($versions) - 1); $k >= 0; $k--)
 		{
-			$current	= $versions[$k];
-			$previous		= ($k - 1) >= 0 ? $versions[$k - 1] : null;
-			$next			= ($k + 1) <= (count($versions) - 1) ? $versions[$k + 1] : null;
+			$current  = $versions[$k];
+			$previous = ($k - 1) >= 0 ? $versions[$k - 1] : null;
+			$next     = ($k + 1) <= (count($versions) - 1) ? $versions[$k + 1] : null;
 
 			if (!$current['commitStatus'])
 			{
@@ -1667,9 +1737,8 @@ class Repo extends Object
 	/**
 	 * Get file content and write to specified location
 	 *
-	 * @param      array	$params
-	 *
-	 * @return     array
+	 * @param   array  $params
+	 * @return  array
 	 */
 	public function getFileContent($params = array())
 	{
@@ -1679,6 +1748,7 @@ class Repo extends Object
 	/**
 	 * Is file zip?
 	 *
+	 * @param   string   $file
 	 * @return  boolean
 	 */
 	protected function _isZip($file)
@@ -1690,6 +1760,7 @@ class Repo extends Object
 	/**
 	 * Is tar zip?
 	 *
+	 * @param   string   $file
 	 * @return  boolean
 	 */
 	protected function _isTar($file)
@@ -1705,7 +1776,7 @@ class Repo extends Object
 	 */
 	public function getAvailableDiskSpace()
 	{
-		$pParams = Plugin::params( 'projects', 'files' );
+		$pParams = Plugin::params('projects', 'files');
 		$projectParams = $this->get('project')->params;
 		$quota = $this->get('project')->config()->get('defaultQuota', '1');
 
@@ -1722,7 +1793,7 @@ class Repo extends Object
 		{
 			$this->_quota = $projectParams->get('quota')
 						? $projectParams->get('quota')
-						: Helpers\Html::convertSize( floatval($quota), 'GB', 'b');
+						: Helpers\Html::convertSize(floatval($quota), 'GB', 'b');
 		}
 
 		return $this->_quota - $diskUsage;
