@@ -32,18 +32,27 @@
 
 namespace Components\Projects\Site\Controllers;
 
+
 use Components\Projects\Tables;
 use Components\Projects\Models;
 use Components\Projects\Helpers;
-use Components\Projects\Helpers\LayoutHelper;
+use Components\Projects\Helpers\AccessHelper;
 use Components\Projects\Models\Orm\Description;
 use Components\Projects\Models\Orm\Description\Field;
 use Exception;
 use stdClass;
+use Request;
+use Route;
+use Event;
+use User;
+use Date;
+use Lang;
+use App;
 
-require_once Component::path('com_projects') . DS . 'models' . DS . 'orm' . DS . 'description.php';
-require_once Component::path('com_projects') . DS . 'models' . DS . 'orm' . DS . 'description' . DS . 'field.php';
-require_once Component::path('com_projects') . '/helpers/layoutHelper.php';
+require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'description.php';
+require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'description' . DS . 'field.php';
+require_once dirname(dirname(__DIR__)) . '/helpers/accessHelper.php';
+require_once Component::path('com_projects') . '/models/orm/owner.php';
 
 /**
  * Primary component controller
@@ -53,7 +62,7 @@ class Projects extends Base
 	/**
 	 * Determines task being called and attempts to execute it
 	 *
-	 * @return	void
+	 * @return  void
 	 */
 	public function execute()
 	{
@@ -116,6 +125,65 @@ class Projects extends Base
 		echo json_encode($json);
 	}
 
+	/**
+	 * Allow user to request membership to a public project.
+	 *
+	 * @return  void
+	 */
+	public function requestAccessTask()
+	{
+		Request::checkToken('get');
+		if (!$this->model->allowMembershipRequest())
+		{
+			App::abort(404, 'Invalid request');
+		}
+
+		$project = Request::getVar('alias');
+		$task = $this->_task;
+		$return = Route::url('index.php?option=com_projects&alias=' . $project, false);
+		if (User::isGuest())
+		{
+			$redirectUrl = Route::url('index.php?option=com_users&view=login&return=' . base64_encode($return), false);
+			App::redirect($redirectUrl);
+		}
+
+		if (!$this->model->member())
+		{
+			if ($this->model->exists())
+			{
+				$userId = User::getInstance()->get('id');
+				$member = \Components\Projects\Models\Orm\Owner::blank();
+				$member->set('projectid', $this->model->get('id'));
+				$member->set('userid', $userId);
+				$member->set('status', 3);
+				$currentTime = Date::of()->toSql();
+				$member->set('added', $currentTime);
+				if ($member->save())
+				{
+					$managers = \Components\Projects\Models\Orm\Owner::getProjectManagers($this->model->get('id'));
+					$emails = array();
+					foreach ($managers as $manager)
+					{
+						$emails[] = $manager->user->email;
+					}
+					$subject = Lang::txt('COM_PROJECTS_EMAIL_MEMBERSHIPREQUEST_SUBJECT');
+					$message = Lang::txt('COM_PROJECTS_EMAIL_MEMBERSHIPREQUEST_MESSAGE', $member->user->name, $member->user->email);
+					\Components\Projects\Helpers\Html::sendHUBMessage(
+						$this->_option,
+						$this->model,
+						$emails,
+						$subject,
+						'projects_project_membershiprequest',
+						'memberrequest',
+						$message
+					);
+					Notify::success(Lang::txt('COM_PROJECTS_MEMBERSHIPREQUEST_SUCCESS'));
+				}
+			}
+		}
+		App::redirect(Route::url('index.php?option=com_projects&alias=' . $project, false));
+	}
+
 	/**
 	 * Intro to projects (main view)
 	 *
@@ -417,7 +485,7 @@ class Projects extends Base
 		}
 
 		// Determine layout to load
-		$layout = ($this->model->access('member')) ? 'internal' : 'external';
+		$layout = ($this->model->access('member') || AccessHelper::allowPublicAccess($subdir)) ? 'internal' : 'external';
 		$layout = $this->model->access('member')
 				&& $preview && $this->model->isPublic()
 				? 'external' : $layout;
@@ -514,7 +582,7 @@ class Projects extends Base
 		}
 
 		// Private project
-		if (!$this->model->isPublic() && $layout != 'invited' && $subdir != 'public')
+		if (!$this->model->isPublic() && $layout != 'invited' && !AccessHelper::allowPublicAccess($subdir))
 		{
 			// Login required
 			if (User::isGuest())
@@ -565,8 +633,6 @@ class Projects extends Base
 		// Get tabbed plugins
 		$this->view->tabs = Helpers\Html::getTabs($plugins);
 
-		$layout = LayoutHelper::accessPublic(Request::getVar('subdir'), $layout);
-
 		// Go through plugins
 		$this->view->content = '';
 		if ($layout == 'internal')
@@ -785,7 +851,7 @@ class Projects extends Base
 		// Save new alias & title
 		if (!$this->getError())
 		{
-			$this->model->set('title', \Hubzero\Utility\String::truncate($title, 250));
+			$this->model->set('title', \Hubzero\Utility\Str::truncate($title, 250));
 			$this->model->set('alias', $name);
 
 			$state = $this->_setupComplete == 3 ? 0 : 1;
@@ -1103,7 +1169,7 @@ class Projects extends Base
 			// Save comment
 			if (trim($comment) != '')
 			{
-				$comment = \Hubzero\Utility\String::truncate($comment, 500);
+				$comment = \Hubzero\Utility\Str::truncate($comment, 500);
 				$comment = \Hubzero\Utility\Sanitize::stripAll($comment);
 				if (!$approve)
 				{
