@@ -765,7 +765,7 @@ class Items extends AdminController
 
 		// Save incoming
 		$this->model->version->title        = $title;
-		$this->model->version->abstract     = \Hubzero\Utility\String::truncate($abstract, 250);
+		$this->model->version->abstract     = \Hubzero\Utility\Str::truncate($abstract, 250);
 		$this->model->version->description  = $description;
 		$this->model->version->metadata     = $metadata;
 		$this->model->version->release_notes= $release_notes;
@@ -836,7 +836,7 @@ class Items extends AdminController
 		$rt->tag_object(User::get('id'), $id, $tags, 1, true);
 
 		// Email config
-		$pubtitle = \Hubzero\Utility\String::truncate($this->model->version->title, 100);
+		$pubtitle = \Hubzero\Utility\Str::truncate($this->model->version->title, 100);
 		$subject  = Lang::txt('Version') . ' ' . $this->model->version->version_label . ' '
 					. Lang::txt('COM_PUBLICATIONS_OF') . ' '
 					. strtolower(Lang::txt('COM_PUBLICATIONS_PUBLICATION'))
@@ -944,7 +944,7 @@ class Items extends AdminController
 					break;
 
 				case 'revert':
-					// What is this? This sets it to the state it's alreayd in.
+					// What is this? This sets it to the state it's already in.
 					//$this->model->version->state = $state ? $state : 4;
 					$this->model->version->state = 3;
 					$activity = Lang::txt('COM_PUBLICATIONS_ACTIVITY_ADMIN_REVERTED');
@@ -1009,10 +1009,10 @@ class Items extends AdminController
 					// Append comment to activity
 					if ($message && $aid)
 					{
-						require_once (PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'tables' . DS . 'comment.php');
+						require_once \Component::path('com_projects') . DS . 'tables' . DS . 'comment.php';
 						$objC = new \Components\Projects\Tables\Comment($this->database);
 
-						$comment = \Hubzero\Utility\String::truncate($message, 250);
+						$comment = \Hubzero\Utility\Str::truncate($message, 250);
 						$comment = \Hubzero\Utility\Sanitize::stripAll($comment);
 
 						$objC->itemid           = $aid;
@@ -1088,26 +1088,27 @@ class Items extends AdminController
 		// Append any errors
 		if ($this->getError())
 		{
-			$output .= ' ' . $this->getError();
+			Notify::error($this->getError());
+		}
+
+		if ($output)
+		{
+			Notify::success($output);
 		}
 
 		// Redirect to edit view?
 		if ($redirect)
 		{
 			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&task=edit' . '&id[]=' . $id . '&version=' . $this->model->get('version_number'), false),
-				$output
+				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&task=edit' . '&id[]=' . $id . '&version=' . $this->model->get('version_number'), false)
 			);
 		}
 		else
 		{
 			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-				$output
+				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
 			);
 		}
-
-		return;
 	}
 
 	/**
@@ -1271,7 +1272,7 @@ class Items extends AdminController
 
 		$version = count($ids) == 1 ? Request::getVar('version', 'all') : 'all';
 
-		require_once (PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'tables' . DS . 'activity.php');
+		require_once \Component::path('com_projects') . DS . 'tables' . DS . 'activity.php';
 
 		foreach ($ids as $id)
 		{
@@ -1355,11 +1356,32 @@ class Items extends AdminController
 					$objP->deleteExistence($id);
 
 					// Delete related publishing activity from feed
-					$objAA = new \Components\Projects\Tables\Activity($this->database);
-					$objAA->deleteActivityByReference($projectId, $id, 'publication');
+					$activities = \Hubzero\Activity\Log::all()
+						->whereEquals('scope', 'publication')
+						->whereEquals('scope_id', $id)
+						->whereEquals('state', 1)
+						->rows()
+						->toArray();
+
+					$logs = array();
+					foreach ($activities as $activity)
+					{
+						$logs[] = $activity['id'];
+					}
+
+					$past = \Hubzero\Activity\Recipient::all()
+						->whereIn('log_id', $logs)
+						->whereEquals('state', 1)
+						->rows();
+
+					foreach ($past as $p)
+					{
+						$p->set('state', 0);
+						$p->save();
+					}
 
 					// Build publication path
-					$path =  PATH_APP . DS . trim($this->config->get('webpath'), DS) . DS . \Hubzero\Utility\String::pad($id);
+					$path =  PATH_APP . DS . trim($this->config->get('webpath'), DS) . DS . \Hubzero\Utility\Str::pad($id);
 
 					// Delete all files
 					if (is_dir($path))
@@ -1549,7 +1571,7 @@ class Items extends AdminController
 		$pub->setCuration();
 
 		// Produce archival package
-		if (!$pub->_curationModel->package())
+		if (!$pub->_curationModel->package(true))
 		{
 			// Checkin the resource
 			$pub->publication->checkin();
