@@ -63,8 +63,8 @@ class Html
 
 		$base = DS . trim($base, DS);
 
-		$pub_dir     =  \Hubzero\Utility\String::pad($pid);
-		$version_dir =  \Hubzero\Utility\String::pad($vid);
+		$pub_dir     =  \Hubzero\Utility\Str::pad($pid);
+		$version_dir =  \Hubzero\Utility\Str::pad($vid);
 		$path        = $base . DS . $pub_dir . DS . $version_dir;
 		$path        = $filedir ? $path . DS . $filedir : $path;
 		$path        = $root ? PATH_APP . $path : $path;
@@ -130,7 +130,7 @@ class Html
 	public static function showContributors($contributors = '', $showorgs = false, $showaslist = false, $incSubmitter = false, $format = false)
 	{
 		$view = new \Hubzero\Component\View(array(
-			'base_path' => PATH_CORE . DS . 'components' . DS . 'com_publications' . DS . 'site',
+			'base_path' => dirname(__DIR__) . DS . 'site',
 			'name'      => 'view',
 			'layout'    => '_contributors'
 		));
@@ -155,7 +155,7 @@ class Html
 			return false;
 		}
 		$view = new \Hubzero\Component\View(array(
-			'base_path' => PATH_CORE . DS . 'components' . DS . 'com_publications' . DS . 'site',
+			'base_path' => dirname(__DIR__) . DS . 'site',
 			'name'      => 'view',
 			'layout'    => '_supportingdocs',
 		));
@@ -340,7 +340,6 @@ class Html
 	public static function citation($cite, $pub, $citations)
 	{
 		include_once Component::path('com_citations') . DS . 'helpers' . DS . 'format.php';
-		include_once Component::path('com_citations') . DS . 'tables' . DS . 'type.php';
 
 		$cconfig  = Component::params('com_citations');
 
@@ -360,7 +359,7 @@ class Html
 
 			// The following line was meant to remove quote marks from around the title
 			// Instead, it removes all quote marks, resulting in invalid HTML.
-			// So, we try a little mroe specific approach.
+			// So, we try a little more specific approach.
 			//$formatted = str_replace('"', '', $formatted);
 			$formatted = str_replace(array('<b>"', '"</b>'), array('<b>', '</b>'), $formatted);
 
@@ -543,7 +542,7 @@ class Html
 				$project .= $publication->access('owner')
 					? ' <a href="' . Route::url($publication->project()->link()) . '">'
 					: ' <strong>';
-				$project .= \Hubzero\Utility\String::truncate($publication->project()->get('title'), 50);
+				$project .= \Hubzero\Utility\Str::truncate($publication->project()->get('title'), 50);
 				$project .= $publication->access('owner') ? '</a>' : '</strong>';
 				$msg .= ' <span class="fromproject">' . $project . '</span>';
 			}
@@ -838,7 +837,7 @@ class Html
 		?>
 		<div id="plg-header">
 			<h3 class="publications c-header">
-				<a href="<?php echo Route::url($pub->link('editbase')); ?>" title="<?php echo $tabtitle; ?>"><?php echo $tabtitle; ?></a> &raquo; <span class="restype indlist"><?php echo $typetitle; ?></span> <span class="indlist">"<?php if ($append) { echo '<a href="' . $pubUrl . '" >'; } ?><?php echo \Hubzero\Utility\String::truncate($pub->get('title'), 65); ?>"<?php if ($append) { echo '</a>'; } ?></span>
+				<a href="<?php echo Route::url($pub->link('editbase')); ?>" title="<?php echo $tabtitle; ?>"><?php echo $tabtitle; ?></a> &raquo; <span class="restype indlist"><?php echo $typetitle; ?></span> <span class="indlist">"<?php if ($append) { echo '<a href="' . $pubUrl . '" >'; } ?><?php echo \Hubzero\Utility\Str::truncate($pub->get('title'), 65); ?>"<?php if ($append) { echo '</a>'; } ?></span>
 				<?php if ($append) { echo $append; } ?>
 			</h3>
 		</div>
@@ -856,7 +855,7 @@ class Html
 	{
 		?>
 		<h3 class="prov-header">
-			<a href="<?php echo Route::url($pub->link('editbase')); ?>"><?php echo ucfirst(Lang::txt('PLG_PROJECTS_PUBLICATIONS_MY_SUBMISSIONS')); ?></a> &raquo; "<?php echo \Hubzero\Utility\String::truncate($pub->get('title'), 65); ?>"
+			<a href="<?php echo Route::url($pub->link('editbase')); ?>"><?php echo ucfirst(Lang::txt('PLG_PROJECTS_PUBLICATIONS_MY_SUBMISSIONS')); ?></a> &raquo; "<?php echo \Hubzero\Utility\Str::truncate($pub->get('title'), 65); ?>"
 			<?php if ($append) { echo $append; } ?>
 		</h3>
 		<?php
@@ -878,7 +877,7 @@ class Html
 	public static function primaryButton($class, $href, $msg, $xtra = '', $title = '', $action = '', $disabled = false, $pop = '')
 	{
 		$view = new \Hubzero\Component\View(array(
-			'base_path' => PATH_CORE . DS . 'components' . DS . 'com_publications' . DS . 'site',
+			'base_path' => dirname(__DIR__) . DS . 'site',
 			'name'      => 'view',
 			'layout'    => '_primary'
 		));
@@ -1112,7 +1111,7 @@ class Html
 
 			foreach ($rows as $row)
 			{
-				$path = DS . $base . DS . \Hubzero\Utility\String::pad($row->id);
+				$path = DS . $base . DS . \Hubzero\Utility\Str::pad($row->id);
 				// For simple reporting, we only count the current version's raw content size
 				// This does not count the bundle or previous versions of each publication	
 				if ($simple)
@@ -1210,7 +1209,7 @@ class Html
 
 		// Get message body
 		$eview = new \Hubzero\Mail\View(array(
-			'base_path' => PATH_CORE . DS . 'components' . DS . 'com_publications' . DS . 'site',
+			'base_path' => dirname(__DIR__) . DS . 'site',
 			'name'      => 'emails',
 			'layout'    => '_plain'
 		));
