@@ -37,6 +37,11 @@ use Hubzero\Filesystem\Entity;
 use Components\Projects\Models\Orm\Connection;
 use stdClass;
 use ZipArchive;
+use Filesystem;
+use Route;
+use Lang;
+use User;
+use Date;
 
 /**
  * Handles a file attachment
@@ -142,6 +147,7 @@ class File extends Base
 		$bundleName           = $versionParams->get('element' . $elementId . 'bundlename', $configs->title);
 		$configs->bundleTitle = $bundleName ? $bundleName : $configs->title;
 		$configs->bundleName  = $bundleName ? $bundleName . '.zip' : 'bundle.zip';
+		$configs->bundleOverwrite = $versionParams->get('bundleOverwrite', false);
 
 		// Allow rename?
 		$configs->allowRename = false;
@@ -193,7 +199,7 @@ class File extends Base
 		// Add inside bundles
 		if ($configs->multiZip == 1 && $attachments && count($attachments) > 1)
 		{
-			$filePath = $this->bundle($attachments, $configs, false);
+			$filePath = $this->bundle($attachments, $configs, $configs->bundleOverwrite);
 			$bPath    = $configs->pubBase . DS . 'bundles';
 			if (is_file($filePath))
 			{
@@ -422,6 +428,11 @@ class File extends Base
 			// Serve individually
 			foreach ($attachments as $attach)
 			{
+				if ($attach->type != $this->_name)
+				{
+					continue;
+				}
+
 				// Get file path
 				$fpath = $this->getFilePath($attach->path, $attach->id, $configs, $attach->params);
 
@@ -702,7 +713,7 @@ class File extends Base
 	public function serve($element, $elementId, $pub, $blockParams, $itemId = 0)
 	{
 		// Incoming
-		$forceDownload = Request::getInt('download', 0); // Force downlaod action?
+		$forceDownload = Request::getInt('download', 0); // Force download action?
 
 		// Get configs
 		$configs = $this->getConfigs($element->params, $elementId, $pub, $blockParams);
@@ -859,20 +870,36 @@ class File extends Base
 			return $bundle;
 		}
 
+		$files = array();
+		foreach ($attachments as $attach)
+		{
+			$fpath = $this->getFilePath($attach->path, $attach->id, $configs, $attach->params);
+			$fname = trim(str_replace($configs->pubPath . DS, '', $fpath), DS);
+			// Window's built-in archive utility can't seem to handle paths with "./" in them
+			// So, we strip out "./", It has no effect on the resulting path.
+			// @TODO: Maybe find a better, more reliable way to do this?
+			$fname = str_replace('./', '', $fname);
+
+			if (is_file($fpath))
+			{
+				$files[$fpath] = $fname;
+			}
+		}
+
+		if (!count($files))
+		{
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_PUBLICATION_NO_FILES_FOUND'));
+			return false;
+		}
+
 		$zip = new ZipArchive;
 		if ($zip->open($bundle, ZipArchive::CREATE | ZipArchive::OVERWRITE) === true)
 		{
 			$i = 0;
-			foreach ($attachments as $attach)
+			foreach ($files as $fpath => $fname)
 			{
-				$fpath = $this->getFilePath($attach->path, $attach->id, $configs, $attach->params);
-				$fname = trim(str_replace($configs->pubPath . DS, '', $fpath), DS);
-
-				if (is_file($fpath))
-				{
-					$zip->addFile($fpath, $fname);
-					$i++;
-				}
+				$zip->addFile($fpath, $fname);
+				$i++;
 			}
 			$zip->close();
 		}
@@ -915,7 +942,7 @@ class File extends Base
 		}
 
 		// Git helper
-		include_once PATH_CORE . DS . 'components' . DS .'com_projects' . DS . 'helpers' . DS . 'githelper.php';
+		include_once \Component::path('com_projects') . DS . 'helpers' . DS . 'githelper.php';
 		$this->_git = new \Components\Projects\Helpers\Git($configs->path);
 
 		// Counter
@@ -937,7 +964,7 @@ class File extends Base
 			{
 				if (isset($matches[1]))
 				{
-					require_once PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'models' . DS . 'orm' . DS . 'connection.php';
+					require_once \Component::path('com_projects') . DS . 'models' . DS . 'orm' . DS . 'connection.php';
 
 					// Grab the connection id
 					$connection = $matches[1];
