@@ -32,7 +32,7 @@
 
 namespace Components\Publications\Models;
 
-use Hubzero\Base\Object;
+use Hubzero\Base\Obj;
 use Components\Publications\Helpers;
 use Components\Publications\Tables;
 use stdClass;
@@ -62,7 +62,7 @@ require_once dirname(__DIR__) . DS . 'helpers' . DS . 'html.php';
  *
  * Parses curation flow into view block for user, admin and curator
  */
-class Curation extends Object
+class Curation extends Obj
 {
 	/**
 	 * Database
@@ -1511,6 +1511,14 @@ class Curation extends Object
 		$status->authornotice  = null;
 		$status->updated_by    = 0;
 
+		// Make sure the step exists
+		// If it doesn't, this is possibly a block that was
+		// disabled on the master type and later enabled.
+		if (!isset($pub->_curationModel->_progress->blocks->$step))
+		{
+			return $status;
+		}
+
 		if ($elId)
 		{
 			$reviewStatus = $pub->_curationModel->_progress->blocks->$step->review->elements->$elId;
