@@ -79,10 +79,10 @@ class Publications extends SiteController
 
 		// Register tasks
 		$this->registerTask('view', 'page');
+		$this->registerTask('watch', 'page');
 		$this->registerTask('download', 'serve');
 		$this->registerTask('video', 'serve');
 		$this->registerTask('play', 'serve');
-		$this->registerTask('watch', 'serve');
 
 		$this->registerTask('wiki', 'wikipage');
 		$this->registerTask('submit', 'contribute');
@@ -99,6 +99,11 @@ class Publications extends SiteController
 		{
 			$this->_task = 'intro';
 		}
+		if (!$this->_id && !$this->_alias && in_array($this->_task, array('view', 'page')))
+		{
+			Request::setVar('task', 'intro');
+			$this->_task = 'intro';
+		}
 
 		parent::execute();
 	}
@@ -140,6 +145,10 @@ class Publications extends SiteController
 		$pointer       = $this->_id ? '&id=' . $this->_id : '&alias=' . $this->_alias;
 		$this->_route  = 'index.php?option=' . $this->_option;
 		$this->_route .= $this->_identifier ? $pointer : '';
+		if ($active = Request::getWord('active'))
+		{
+			$this->_route .= '&active=' . $active;
+		}
 	}
 
 	/**
@@ -1014,7 +1023,7 @@ class Publications extends SiteController
 
 			case 'bibtex':
 			default:
-				include_once(PATH_CORE . DS . 'components' . DS . 'com_citations' . DS . 'helpers' . DS . 'BibTex.php');
+				include_once Component::path('com_citations') . DS . 'helpers' . DS . 'BibTex.php';
 
 				$bibtex = new \Structures_BibTex();
 				$addarray = array();
@@ -1195,7 +1204,7 @@ class Publications extends SiteController
 
 		// Load language file
 		Lang::load('com_projects') ||
-		Lang::load('com_projects', PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'site');
+		Lang::load('com_projects', Component::path('com_projects') . DS . 'site');
 
 		// Instantiate a new view
 		$this->view  = new \Hubzero\Component\View(array(
@@ -1390,7 +1399,7 @@ class Publications extends SiteController
 
 		// Load language file
 		Lang::load('com_projects') ||
-		Lang::load('com_projects', PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'site');
+		Lang::load('com_projects', Component::path('com_projects') . DS . 'site');
 
 		// Set page title
 		$this->_task_title = Lang::txt('COM_PUBLICATIONS_FORK');
@@ -1594,19 +1603,18 @@ class Publications extends SiteController
 		}
 
 		// Copy citations
-		include_once Component::path('com_citations')  . '/tables/association.php';
+		include_once Component::path('com_citations')  . '/models/association.php';
 
-		$c = new \Components\Citations\Tables\Association($this->database);
-		$citations = $c->getRecords(array(
-			'tbl' => 'publication',
-			'oid' => $pub_id
-		));
+		$citations = \Components\Citations\Models\Association::all()
+			->whereEquals('tbl', 'publication')
+			->whereEquals('oid', $pub_id)
+			->rows();
 		foreach ($citations as $citation)
 		{
-			$ca = new \Components\Citations\Tables\Association($this->database);
-			$ca->cid = $citation->cid;
-			$ca->tbl = $citation->tbl;
-			$ca->oid = $pub_id;
+			$ca = \Components\Citations\Models\Association::blank();
+			$ca->set('cid', $citation->cid);
+			$ca->set('tbl', $citation->tbl);
+			$ca->set('oid', $pub_id);
 
 			if (!$ca->save())
 			{
@@ -1687,6 +1695,10 @@ class Publications extends SiteController
 		// Get manifest from either version record (published) or master type
 		$manifest = $version->get('curation', $publication->type->get('curation'));
 		$curation = json_decode($manifest, true);
+		if (!$curation || json_last_error() !== JSON_ERROR_NONE)
+		{
+			$curation = json_decode($publication->type->get('curation'), true);
+		}
 		$fileParams = array(
 			'directory'    => '',
 			'dirHierarchy' => 1
@@ -1772,6 +1784,8 @@ class Publications extends SiteController
 				App::abort(500, $attachment->getError());
 			}
 
+			// For publications forked into an existing project, we will store all files
+			// in a sub directory to avoid any conflicts.
 			$sub = 'publication_' . $vid . '_' . $version->get('id');
 
 			if ($attachment->get('type') == 'file')
@@ -1854,7 +1868,7 @@ class Publications extends SiteController
 				{
 					Filesystem::makeDirectory($toProj, 0755, true, true);
 
-					if ($pid)
+					if ($pid && $project->params->get('versionTracking'))
 					{
 						// Commit to GIT
 						$fileObj = new \Components\Projects\Models\File(
@@ -1898,7 +1912,7 @@ class Publications extends SiteController
 							App::abort(500, Lang::txt('Failed to copy file "' . $from . $filename . '" to "' . $toProj . $orig . '"'));
 						}
 
-						if ($pid)
+						if ($pid && $project->params->get('versionTracking'))
 						{
 							// Commit to GIT
 							$fileObj = new \Components\Projects\Models\File(
