@@ -33,21 +33,22 @@
 
 namespace Components\Resources\Api\Controllers;
 
-use Components\Resources\Tables\Resource;
-use Components\Resources\Tables\Type;
-use Components\Tags\Models\Cloud;
-use Components\Resources\Models\Orm\Resource as ResourceORM;
+use Components\Resources\Models\Entry;
+use Components\Resources\Models\Type;
 use Hubzero\Component\ApiController;
 use Component;
 use Exception;
 use stdClass;
 use Request;
+use Route;
+use Lang;
+use Date;
 use App;
 
 /**
  * API controller class for resources
  */
-class Entriesv1_1 extends ApiController
+class Entriesv1_0 extends ApiController
 {
 	/**
 	 * Get a list of resources
@@ -98,46 +99,85 @@ class Entriesv1_1 extends ApiController
 		$filters = array(
 			'type'   => Request::getVar('type', ''),
 			'sortby' => Request::getCmd('sortby', 'date'),
-			'limit'  => Request::getInt('limit', Config::get('list_limit')),
+			'limit'  => Request::getInt('limit', \Config::get('list_limit')),
 			'start'  => Request::getInt('limitstart', 0),
 			'search' => Request::getVar('search', '')
 		);
 
-		$admin = false;
-		if (User::authorise('core.admin', 'com_resources'))
-		{
-			$admin = true;
-			$filters['tag'] = '';
-			$searchable = Request::getVar('searchable', false);
-
-			require_once Component::path('com_tags') . '/models/cloud.php';
-			require_once Component::path('com_resources') . '/models/orm/resource.php';
-		}
-
 		if (!in_array($filters['sortby'], array('date', 'date_published', 'date_created', 'date_modified', 'title', 'rating', 'ranking', 'random')))
 		{
 			App::abort(404, Lang::txt('Invalid sort value of "%s" used.', $filters['sortby']));
 		}
 
-		require_once(Component::path('com_resources') . DS . 'tables' . DS . 'resource.php');
-		require_once(Component::path('com_resources') . DS . 'tables' . DS . 'type.php');
+		require_once Component::path('com_resources') . DS . 'models' . DS . 'entry.php';
 
-		$database = App::get('db');
+		$query = Entry::all();
 
-		// Instantiate a resource object
-		$rr = new Resource($database);
+		$r = $query->getTableName();
+
+		$query->whereEquals($r . '.standalone', 1);
+
+		if ($filters['search'])
+		{
+			$filters['search'] = strtolower((string)$filters['search']);
+
+			$query->whereLike($r . '.title', $filters['search'], 1)
+					->orWhereLike($r . '.fulltxt', $filters['search'], 1)
+					->resetDepth();
+		}
+
+		if ($filters['type'])
+		{
+			$query->whereEquals($r . '.type', $filters['type']);
+		}
+
+		$query->whereEquals($r . '.publish_up', '0000-00-00 00:00:00', 1)
+			->orWhere($r . '.publish_up', '<=', Date::toSql(), 1)
+			->resetDepth();
+
+		$query->whereEquals($r . '.publish_down', '0000-00-00 00:00:00', 1)
+			->orWhere($r . '.publish_down', '>=', Date::toSql(), 1)
+			->resetDepth();
+
+		$query->whereEquals($r . '.published', Entry::STATE_PUBLISHED);
+
+		switch ($filters['sortby'])
+		{
+			case 'date_created':
+				$query->order($r . '.created', 'desc');
+				break;
+			case 'date_modified':
+				$query->order($r . '.modified', 'desc');
+				break;
+			case 'title':
+				$query->order($r . '.title', 'asc');
+				$query->order($r . '.publish_up', 'asc');
+				break;
+			case 'rating':
+				$query->order($r . '.rating', 'desc');
+				$query->order($r . '.times_rated', 'desc');
+				break;
+			case 'ranking':
+				$query->order($r . '.ranking', 'desc');
+				break;
+			case 'date':
+			case 'date_published':
+			default:
+				$query->order($r . '.publish_up', 'desc');
+				$query->order($r . '.created', 'desc');
+				break;
+		}
 
 		// encode results and return response
 		$response = new stdClass;
 		$response->records = array();
-		$response->total   = count($rr->getCount($filters, $admin));
+		$response->total   = with(clone $query)->total();
 
 		if ($response->total)
 		{
 			// Get major types
-			$t = new Type($database);
 			$types = array();
-			foreach ($t->getMajorTypes() as $type)
+			foreach (Type::getMajorTypes()->toObject() as $type)
 			{
 				unset($type->params);
 				unset($type->customFields);
@@ -145,117 +185,25 @@ class Entriesv1_1 extends ApiController
 				$types[$type->id] = $type;
 			}
 
-			$records = $rr->getRecords($filters, $admin);
+			$records = $query
+				->paginated()
+				->rows();
 
-			if (isset($searchable) && $admin)
+			$base = rtrim(Request::base(), '/');
+
+			foreach ($records as $record)
 			{
-				foreach ($records as $i => $entry)
+				$entry = $record->toObject();
+				//$entry->params = $record->params->toObject();
+				//$entry->attribs = $record->attribs->toObject();
+				$entry->url = str_replace('/api', '', $base . '/' . ltrim(Route::url($record->link()), '/'));
+
+				if (isset($types[$entry->type]))
 				{
-					$obj = new stdClass;
-
-					if ($entry->alias != '')
-					{
-						$obj->url = '/resources/' . $entry->alias;
-					}
-					else
-					{
-						$obj->url = '/resources/' . $entry->id;
-					}
-
-					$obj->title = $entry->title;
-					$obj->id = 'resource-' . $entry->id;
-					$obj->hubtype = 'resource';
-
-					if (isset($types[$entry->type]))
-					{
-						$obj->type = $types[$entry->type]->type;
-					}
-
-					$description = $entry->fulltxt . ' ' . $entry->introtext;
-					$description = html_entity_decode($description);
-					$description = \Hubzero\Utility\Sanitize::stripAll($description);
-					$obj->description = $description;
-
-					$authors = ResourceORM::one($entry->id)
-						->authors()
-						->select('name')
-						->rows()
-						->toObject();
-
-					$obj->author = array();
-					foreach ($authors as $author)
-					{
-						array_push($obj->author, $author->name);
-					}
-
-					if ($entry->standalone != 1 || $entry->published != 1)
-					{
-						$obj->access_level = 'private';
-					}
-					else
-					{
-						switch ($entry->access)
-						{
-							case 0:
-								$obj->access_level = 'public';
-							break;
-							case 1:
-								$obj->access_level = 'registered';
-							break;
-							case 4:
-							default:
-								$obj->access_level = 'private';
-						}
-					}
-
-					$db = App::get('db');
-					$resource = new Resource($db);
-					$resource->load($entry->id);
-					$groups = $resource->getGroups();
-					$tagCloud = new Cloud($entry->id, 'resources');
-					$tags = $tagCloud->tags()->toObject();
-
-					if (!empty($tags))
-					{
-						foreach ($tags as $tag)
-						{
-							$obj->tags[] = $tag->raw_tag;
-						}
-					}
-
-					if (!empty($groups))
-					{
-						foreach ($groups as &$group)
-						{
-							$group = \Hubzero\User\Group::getInstance($group)->get('gidNumber');
-						}
-						$obj->owner_type = 'group';
-						$obj->owner = $groups;
-					}
-					else
-					{
-						$obj->owner_type = 'user';
-						$obj->owner = $entry->created_by;
-					}
-
-					$response->resources[$i] = $obj;
+					$entry->type = $types[$entry->type];
 				}
-			}
-			else
-			{
-				$base = rtrim(Request::base(), '/');
 
-				foreach ($records as $i => $entry)
-				{
-					$entry->url = str_replace('/api', '', $base . '/' . ltrim(Route::url('index.php?option=com_resources&' . ($entry->alias ? 'alias=' . $entry->alias : 'id=' . $entry->id)), '/'));
-
-					if (isset($types[$entry->type]))
-					{
-						$entry->type = $types[$entry->type];
-					}
-
-					$response->resources[$i] = $entry;
-				}
+				$response->records[] = $entry;
 			}
 		}
 
@@ -305,7 +253,7 @@ class Entriesv1_1 extends ApiController
 		$period   = Request::getVar('period', 'month');
 		$category = Request::getVar('category', 'resources');
 
-		require_once(Component::path('com_whatsnew') . DS . 'helpers' . DS . 'finder.php');
+		require_once Component::path('com_whatsnew') . DS . 'helpers' . DS . 'finder.php';
 
 		$whatsnew = \Components\Whatsnew\Helpers\Finder::getBasedOnPeriodAndCategory($period, $category, $limit);
 
