@@ -32,14 +32,16 @@
 
 namespace Components\Resources\Site\Controllers;
 
-use Components\Resources\Models\Orm\Resource;
+use Components\Resources\Models\Entry;
 use Components\Resources\Models\License;
 use Components\Resources\Models\Type;
 use Components\Resources\Models\Elements;
 use Components\Resources\Helpers\Tags;
 use Components\Resources\Helpers\Html;
+use Components\Tags\Models\Objct;
+use Components\Tags\Models\Tag;
 use Hubzero\Component\SiteController;
-use Hubzero\Utility\String;
+use Hubzero\Utility\Str;
 use Pathway;
 use Request;
 use Route;
@@ -49,10 +51,6 @@ use User;
 use Date;
 use App;
 
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'resource.php');
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'license.php');
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'type.php');
-
 /**
  * Resources controller for creating a resource
  */
@@ -89,7 +87,7 @@ class Create extends SiteController
 			Request::setVar('task', 'login');
 		}
 
-		$row = Resource::oneOrNew(Request::getInt('id', 0));
+		$row = Entry::oneOrNew(Request::getInt('id', 0));
 
 		// Build the title
 		$this->_buildTitle($row);
@@ -343,7 +341,7 @@ class Create extends SiteController
 		if (!is_object($row))
 		{
 			// Instantiate a new resource object
-			$row = Resource::oneOrNew($id);
+			$row = Entry::oneOrNew($id);
 
 			if (!$id)
 			{
@@ -424,7 +422,7 @@ class Create extends SiteController
 		}
 
 		// Load the resource
-		$row = Resource::oneOrFail($id);
+		$row = Entry::oneOrFail($id);
 
 		// Output HTML
 		$this->view
@@ -453,7 +451,7 @@ class Create extends SiteController
 		}
 
 		// Load the resource
-		$row = Resource::oneOrFail($id);
+		$row = Entry::oneOrFail($id);
 
 		// Get groups
 		$groups = User::groups('members');
@@ -475,8 +473,8 @@ class Create extends SiteController
 	/**
 	 * Recursive method for loading hierarchical focus areas (tags)
 	 *
-	 * @param   integer  $id            Resource type ID
-	 * @param   array    $labels        Tags
+	 * @param   string   $type
+	 * @param   array    $labels
 	 * @param   integer  $parent_id     Tag ID
 	 * @param   string   $parent_label  Tag
 	 * @return  void
@@ -487,9 +485,9 @@ class Create extends SiteController
 		{
 			$this->database->setQuery(
 				'SELECT DISTINCT tag
-				FROM #__focus_area_resource_type_rel fr
-				INNER JOIN #__focus_areas f ON f.id = fr.focus_area_id
-				INNER JOIN #__tags t ON t.id = f.tag_id
+				FROM `#__focus_area_resource_type_rel` fr
+				INNER JOIN `#__focus_areas` f ON f.id = fr.focus_area_id
+				INNER JOIN `#__tags` t ON t.id = f.tag_id
 				WHERE fr.resource_type_id = ' . $type
 			);
 			if (!($labels = $this->database->loadColumn()))
@@ -503,23 +501,23 @@ class Create extends SiteController
 			$parent_id
 				// get tags labeled focus area and parented by the tag identified by $parent_id
 				? 'SELECT DISTINCT t.raw_tag AS label, t2.id, t2.tag, t2.raw_tag, t2.description
-					FROM #__tags t
-					INNER JOIN #__tags_object to1 ON to1.tbl = \'tags\' AND to1.tagid = t.id AND to1.label = \'label\'
-					INNER JOIN #__tags_object to2 ON to2.tbl = \'tags\' AND to2.label = \'parent\' AND to2.objectid = to1.objectid
+					FROM `#__tags` t
+					INNER JOIN `#__tags_object` to1 ON to1.tbl = \'tags\' AND to1.tagid = t.id AND to1.label = \'label\'
+					INNER JOIN `#__tags_object` to2 ON to2.tbl = \'tags\' AND to2.label = \'parent\' AND to2.objectid = to1.objectid
 						AND to2.tagid = ' . $parent_id . '
-					INNER JOIN #__tags t2 ON t2.id = to1.objectid
+					INNER JOIN `#__tags` t2 ON t2.id = to1.objectid
 					WHERE t.raw_tag = ' . $this->database->quote($parent_label) . '
 					ORDER BY CASE WHEN t2.raw_tag LIKE \'other%\' THEN 1 ELSE 0 END, t2.raw_tag'
 				// get tags that are labeled focus areas that are not also a parent of another tag labeled as a focus area
 				: 'SELECT DISTINCT t.raw_tag AS label, t2.id, t2.tag, t2.raw_tag, t2.description
-					FROM #__tags t
-					LEFT JOIN #__tags_object to1 ON to1.tagid = t.id AND to1.label = \'label\' AND to1.tbl = \'tags\'
-					INNER JOIN #__tags t2 ON t2.id = to1.objectid
+					FROM `#__tags` t
+					LEFT JOIN `#__tags_object` to1 ON to1.tagid = t.id AND to1.label = \'label\' AND to1.tbl = \'tags\'
+					INNER JOIN `#__tags` t2 ON t2.id = to1.objectid
 					WHERE t.tag IN (' . $labels . ') AND (
 						SELECT COUNT(*)
-						FROM #__tags_object to2
-						INNER JOIN #__tags_object to3 ON to3.tbl = \'tags\' AND to3.label = \'label\' AND to3.objectid = to2.tagid
-						INNER JOIN #__tags t3 ON t3.id = to3.tagid AND t3.tag IN (' . $labels . ')
+						FROM `#__tags_object` to2
+						INNER JOIN `#__tags_object` to3 ON to3.tbl = \'tags\' AND to3.label = \'label\' AND to3.objectid = to2.tagid
+						INNER JOIN `#__tags` t3 ON t3.id = to3.tagid AND t3.tag IN (' . $labels . ')
 						WHERE to2.tbl = \'tags\' AND to2.label = \'parent\' AND to2.objectid = t2.id
 						LIMIT 1
 					) = 0
@@ -559,7 +557,7 @@ class Create extends SiteController
 		$this->_checkProgress($id);
 
 		// Load the resource
-		$row = Resource::oneOrFail($id);
+		$row = Entry::oneOrFail($id);
 
 		// Get focus areas
 		$this->database->setQuery('SELECT type FROM `#__resources` WHERE id = ' . $this->database->quote($id));
@@ -640,7 +638,7 @@ class Create extends SiteController
 		}
 
 		// Load resource info
-		$row = Resource::oneOrFail($id);
+		$row = Entry::oneOrFail($id);
 
 		$usersgroups = array();
 		if (!User::isGuest())
@@ -712,17 +710,14 @@ class Create extends SiteController
 		// Initiate extended database class
 		$fields = Request::getVar('fields', array(), 'post');
 
-		$row = Resource::oneOrNew($fields['id'])->set($fields);
+		$row = Entry::oneOrNew($fields['id'])->set($fields);
 
 		$isNew = $row->get('id') < 1 || substr($row->get('id'), 0, 4) == '9999';
 
-		//$row->created    = ($row->created)    ? $row->created    : Date::toSql();
-		//$row->created_by = ($row->created_by) ? $row->created_by : User::get('id');
-
 		// Set status to "composing"
 		if ($isNew)
 		{
-			$row->set('published', 2);
+			$row->set('published', Entry::STATE_DRAFT);
 		}
 
 		$row->set('published', (int)$row->get('published', 2));
@@ -733,12 +728,12 @@ class Create extends SiteController
 		$row->set('access', (int)$row->get('access', 0));
 
 		$row->set('fulltxt', trim(preg_replace('/\\\/', "%5C", $row->get('fulltxt'))));
-		$row->set('introtext', String::truncate(strip_tags($row->get('fulltxt')), 500));
+		$row->set('introtext', Str::truncate(strip_tags($row->get('fulltxt')), 500));
 
 		// Get custom areas, add wrapper tags, and compile into fulltxt
 		$type = Type::oneOrFail($row->get('type'));
 
-		include_once(PATH_CORE . DS . 'components' . DS . 'com_resources' . DS . 'models' . DS . 'elements.php');
+		include_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'elements.php';
 		$elements = new Elements(array(), $type->customFields);
 		$schema = $elements->getSchema();
 
@@ -873,7 +868,7 @@ class Create extends SiteController
 			Request::setVar('id', $row->get('id'));
 			Request::setVar('authid', User::get('id'));
 
-			include_once(__DIR__ . DS . 'authors.php');
+			include_once __DIR__ . DS . 'authors.php';
 			$authors = new Authors();
 			$authors->saveTask(0);
 		}
@@ -930,7 +925,7 @@ class Create extends SiteController
 		}
 
 		// Load the resource
-		$row = Resource::oneOrFail($id);
+		$row = Entry::oneOrFail($id);
 
 		$prev = $row->get('group_owner');
 
@@ -1027,13 +1022,13 @@ class Create extends SiteController
 		$id = Request::getInt('id', 0);
 
 		$this->database->setQuery(
-			'SELECT 1 FROM #__author_assoc WHERE authorid = ' . User::get('id') . ' AND subtable = \'resources\' AND subid = ' . $id . '
+			'SELECT 1 FROM `#__author_assoc` WHERE authorid = ' . User::get('id') . ' AND subtable = \'resources\' AND subid = ' . $id . '
 			UNION
-			SELECT 1 FROM #__resources WHERE id = ' . $id . ' AND (created_by = ' . User::get('id') . ' OR modified_by = ' . User::get('id') . ')
+			SELECT 1 FROM `#__resources` WHERE id = ' . $id . ' AND (created_by = ' . User::get('id') . ' OR modified_by = ' . User::get('id') . ')
 			UNION
-			SELECT 1 FROM #__users u
-			INNER JOIN #__user_usergroup_map cagam ON cagam.user_id = u.id
-			INNER JOIN #__usergroups caag ON caag.id = cagam.group_id AND (caag.title = \'Super Administrator\' OR caag.title = \'Super Users\' OR caag.title = \'Administrator\')
+			SELECT 1 FROM `#__users` u
+			INNER JOIN `#__user_usergroup_map` cagam ON cagam.user_id = u.id
+			INNER JOIN `#__usergroups` caag ON caag.id = cagam.group_id AND (caag.title = \'Super Administrator\' OR caag.title = \'Super Users\' OR caag.title = \'Administrator\')
 			WHERE u.id = ' . User::get('id')
 		);
 
@@ -1049,11 +1044,11 @@ class Create extends SiteController
 
 		$this->database->setQuery(
 			'SELECT fa.tag_id, t.raw_tag, fa.mandatory_depth AS minimum_depth, 0 AS actual_depth
-			FROM #__focus_areas fa
-			INNER JOIN #__tags t ON t.id = fa.tag_id
-			INNER JOIN #__focus_area_resource_type_rel rtr ON rtr.focus_area_id = fa.id
-			INNER JOIN #__resource_types rt ON rt.id = rtr.resource_type_id
-			INNER JOIN #__resources r ON r.type = rt.id AND r.id = ' . $id . '
+			FROM `#__focus_areas` fa
+			INNER JOIN `#__tags` t ON t.id = fa.tag_id
+			INNER JOIN `#__focus_area_resource_type_rel` rtr ON rtr.focus_area_id = fa.id
+			INNER JOIN `#__resource_types` rt ON rt.id = rtr.resource_type_id
+			INNER JOIN `#__resources` r ON r.type = rt.id AND r.id = ' . $id . '
 			WHERE fa.mandatory_depth IS NOT NULL AND fa.mandatory_depth > 0'
 		);
 		$fas = $this->database->loadAssocList('raw_tag');
@@ -1076,10 +1071,10 @@ class Create extends SiteController
 				}
 				$this->database->setQuery(
 					'SELECT t2.raw_tag AS fa, t2.id AS label_id, t.id
-					FROM #__tags t
-					INNER JOIN #__tags_object to1 ON to1.tbl = \'tags\' AND to1.label = \'label\' AND to1.objectid = t.id
-					INNER JOIN #__tags t2 ON t2.id = to1.tagid
-					INNER JOIN #__focus_areas fa ON fa.tag_id = to1.tagid
+					FROM `#__tags` t
+					INNER JOIN `#__tags_object` to1 ON to1.tbl = \'tags\' AND to1.label = \'label\' AND to1.objectid = t.id
+					INNER JOIN `#__tags` t2 ON t2.id = to1.tagid
+					INNER JOIN `#__focus_areas` fa ON fa.tag_id = to1.tagid
 					WHERE t.tag = ' . $this->database->quote($norm_tag)
 				);
 				if (($row = $this->database->loadAssoc()))
@@ -1096,9 +1091,9 @@ class Create extends SiteController
 		{
 			$this->database->setQuery(
 				'SELECT t.tag, t.id
-				FROM #__tags_object to1
-				INNER JOIN #__tags t ON t.id = to1.tagid
-				INNER JOIN #__tags_object to2 ON to2.tagid = ' . $tag[4] . ' AND to2.tbl = \'tags\' AND to2.objectid = to1.tagid
+				FROM `#__tags_object` to1
+				INNER JOIN `#__tags` t ON t.id = to1.tagid
+				INNER JOIN `#__tags_object` to2 ON to2.tagid = ' . $tag[4] . ' AND to2.tbl = \'tags\' AND to2.objectid = to1.tagid
 				WHERE to1.objectid = ' . $tag[3] . ' AND to1.tbl = \'tags\' AND to1.label = \'parent\''
 			);
 			$any_match = false;
@@ -1127,9 +1122,9 @@ class Create extends SiteController
 					{
 						$this->database->setQuery(
 							'SELECT t.id
-							FROM #__tags_object to1
-							INNER JOIN #__tags t ON t.id = to1.tagid
-							INNER JOIN #__tags_object to2 ON to2.tagid = ' . $tag[4] . ' AND to2.tbl = \'tags\' AND to2.objectid = to1.tagid
+							FROM `#__tags_object` to1
+							INNER JOIN `#__tags` t ON t.id = to1.tagid
+							INNER JOIN `#__tags_object` to2 ON to2.tagid = ' . $tag[4] . ' AND to2.tbl = \'tags\' AND to2.objectid = to1.tagid
 							WHERE to1.objectid IN (' . implode(',', $parent_id) . ') AND to1.tbl = \'tags\' AND to1.label = \'parent\''
 						);
 						$parent_id = $this->database->loadColumn();
@@ -1180,19 +1175,112 @@ class Create extends SiteController
 			}
 		}
 
-		$tags = array();
-		foreach ($push as $tag)
-		{
-			$tags[] = $tag[0];
-		}
-		$tags = implode(', ', $tags);
+		$resourceTagsDiff = $this->_diffResourceTags($id, $push);
 
-		$rt = new Tags($id);
-		$this->database->setQuery('DELETE FROM `#__tags_object` WHERE tbl = \'resources\' AND objectid = ' . $id);
-		$this->database->execute();
-		foreach ($push as $tag)
+		$this->_destroyRemovedTags($resourceTagsDiff['removed']);
+		$this->_addNewTags($id, $resourceTagsDiff['added']);
+	}
+
+	/*
+	 * Calculate which tag associations need to be created & destroyed for a resource
+	 *
+	 * @param    integer   $resourceId        Resource record ID
+	 * @param    array     $associationData   Tag association data
+	 * @return   array
+	 */
+	protected function _diffResourceTags($resourceId, $associationData)
+	{
+		$diff = [];
+
+		$normalizedTagNames = array_map(function ($tag) {
+			return $tag[1];
+		}, $associationData);
+
+		$diff['removed'] = $this->_calculateRemovedTagAssociations($resourceId, $normalizedTagNames);
+		$diff['added'] = $this->_calculateNewTagAssociations($resourceId, $normalizedTagNames, $associationData);
+
+		return $diff;
+	}
+
+	/*
+	 * Determine which tags have been disassociated from a given resource based on list of tag names
+	 *
+	 * @param   integer   $resourceId   Resource record ID
+	 * @param   array     $tagNames     Normalized tag names
+	 * @return  HUBzero\Rows
+	 */
+	protected function _calculateRemovedTagAssociations($resourceId, $tagNames)
+	{
+		$tagNamesString = "'" . implode("','", $tagNames) . "'";
+
+		$removedTagAssociations = Objct::all()
+			->select('#__tags_object.*')
+			->join('#__tags', 'tagid', '#__tags.id')
+			->whereEquals('tbl', 'resources')
+			->whereEquals('objectid', $resourceId)
+			->where('#__tags_object.label', '!=', 'badge')
+			->whereRaw("#__tags.tag NOT IN ($tagNamesString)")
+			->rows();
+
+		return $removedTagAssociations;
+	}
+
+	/*
+	 * Determines which data should be used to create new tag associations
+	 *
+	 * @param   integer   $resourceId        Resource record ID
+	 * @param   array     $tagNames          Normalized tag names
+	 * @param   array     $associationData   Tag association data
+	 * @return  array
+	 */
+	protected function _calculateNewTagAssociations($resourceId, $tagNames, $associationData)
+	{
+		$newTags = [];
+		$currentTagNames = Objct::all()
+			->select('#__tags.tag')
+			->join('#__tags', 'tagid', '#__tags.id')
+			->whereEquals('tbl', 'resources')
+			->whereEquals('objectid', $resourceId)
+			->where('#__tags_object.label', '!=', 'badge')
+			->rows()->toArray();
+
+		foreach($tagNames as $i => $tagName)
 		{
-			$rt->add($tag[0], User::get('id'), 0, 1, ($tag[2] ? $tag[2] : ''));
+			if (!in_array($tagName, $currentTagNames))
+			{
+				$newTags[] = $associationData[$i];
+			}
+		}
+
+		return $newTags;
+	}
+
+	/*
+	 * Destroy tag associations removed from a resource's list of tags
+	 *
+	 * @param    HUBzero\Rows  $removedTagAssociations   Removed tag association records
+	 * @return   void
+	 */
+	protected function _destroyRemovedTags($removedTagAssociations)
+	{
+		$removedTagAssociations->destroyAll();
+	}
+
+	/*
+	 * Create tag associations for tags added to a resource's list of tags
+	 *
+	 * @param    integer   $resourceId   Resource record ID
+	 * @param    array     $newTags      Data for new tag associations
+	 * @return   void
+	 */
+	protected function _addNewTags($resourceId, $newTags)
+	{
+		$currentUserId = User::get('id');
+		$tagHelper = new Tags($resourceId);
+
+		foreach ($newTags as $tag)
+		{
+			$tagHelper->add($tag[0], $currentUserId, 0, 1, ($tag[2] ? $tag[2] : ''));
 		}
 	}
 
@@ -1213,11 +1301,11 @@ class Create extends SiteController
 		}
 
 		// Load resource info
-		$resource = Resource::oneOrFail($id);
+		$resource = Entry::oneOrFail($id);
 
 		// Set a flag for if the resource was already published or not
 		$published = 0;
-		if ($resource->get('published') != 2)
+		if ($resource->get('published') != Entry::STATE_DRAFT)
 		{
 			$published = 1;
 		}
@@ -1264,7 +1352,7 @@ class Create extends SiteController
 				}
 
 				// Set status to published
-				$resource->set('published', 1);
+				$resource->set('published', Entry::STATE_PUBLISHED);
 				$resource->set('publish_up', Date::toSql());
 
 				$activity = 'published';
@@ -1278,13 +1366,13 @@ class Create extends SiteController
 				if (in_array(User::get('username'), $apu))
 				{
 					// Set status to published
-					$resource->set('published', 1);
+					$resource->set('published', Entry::STATE_PUBLISHED);
 					$resource->set('publish_up', Date::toSql());
 				}
 				else
 				{
 					// Set status to pending review (submitted)
-					$resource->set('published', 3);
+					$resource->set('published', Entry::STATE_PENDING);
 				}
 			}
 
@@ -1408,10 +1496,9 @@ class Create extends SiteController
 			}
 
 			// set license
-			$params = new \Hubzero\Config\Registry($resource->get('params'));
-			$params->set('license', $license);
+			$resource->params->set('license', $license);
 
-			$resource->set('params', $params->toString());
+			$resource->set('params', $resource->params->toString());
 		}
 
 		// Save the resource
@@ -1465,7 +1552,7 @@ class Create extends SiteController
 		}
 
 		// Load the resource
-		$resource = Resource::oneOrNew($id);
+		$resource = Entry::oneOrNew($id);
 
 		// Incoming step
 		$step = Request::getVar('step', 1);
@@ -1515,10 +1602,10 @@ class Create extends SiteController
 				}
 
 				// Check if the resource was "published"
-				if ($resource->get('published') == 1)
+				if ($resource->get('published') == Entry::STATE_PUBLISHED)
 				{
 					// It was, so we can only mark it as "deleted"
-					$resource->set('published', 4);
+					$resource->set('published', Entry::STATE_TRASHED);
 
 					if (!$resource->save())
 					{
@@ -1580,13 +1667,13 @@ class Create extends SiteController
 		if ($id)
 		{
 			// Load the resource
-			$resource = Resource::oneOrFail($id);
+			$resource = Entry::oneOrFail($id);
 
 			// Check if it's in pending status
-			if ($resource->get('published') == 3)
+			if ($resource->get('published') == Entry::STATE_PENDING)
 			{
 				// Set it back to "draft" status
-				$resource->set('published', 2);
+				$resource->set('published', Entry::STATE_DRAFT);
 
 				// Save changes
 				$resource->save();
@@ -1633,7 +1720,7 @@ class Create extends SiteController
 
 		if ($id)
 		{
-			$resource = Resource::oneOrNew($id);
+			$resource = Entry::oneOrNew($id);
 			$total = $resource->children()->total();
 		}
 
@@ -1652,7 +1739,7 @@ class Create extends SiteController
 
 		if ($id)
 		{
-			$resource = Resource::oneOrNew($id);
+			$resource = Entry::oneOrNew($id);
 			$total = $resource->authors()->total();
 		}
 
@@ -1670,7 +1757,7 @@ class Create extends SiteController
 		if ($id)
 		{
 			$rt = new Tags($id);
-			$tags = $rt->tags()->count();
+			$tags = $rt->tags('count');
 
 			if ($tags > 0)
 			{
@@ -1689,7 +1776,7 @@ class Create extends SiteController
 	 */
 	public function step_review_check($id)
 	{
-		$resource = Resource::oneOrNew($id);
+		$resource = Entry::oneOrNew($id);
 
 		if ($resource->get('published') == 1)
 		{
