@@ -67,7 +67,6 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 
 		$lang = \App::get('language');
 		return $lang->load(strtolower($extension), $basePath, null, false, true)
-			|| $lang->load(strtolower($extension), PATH_APP . DS . 'plugins' . DS . $this->_type . DS . $this->_name, null, false, true)
 			|| $lang->load(strtolower($extension), PATH_APP . DS . 'plugins' . DS . $this->_type . DS . $this->_name, null, false, true)
 			|| $lang->load(strtolower($extension), PATH_CORE . DS . 'plugins' . DS . $this->_type . DS . $this->_name, null, false, true);
 	}
@@ -280,9 +279,6 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 				case 'events':
 					$this->events();
 					break;
-				case 'unregister':
-					$this->unregister();
-					break;
 				default:
 					$arr['html'] = $this->display();
 					break;
@@ -305,7 +301,6 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 		return $arr;
 	}
 
-
 	/**
 	 * Display a calendar
 	 *
@@ -621,10 +616,9 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 		//load com_events params file for registration fields
 		$view->registrationFields = new \Hubzero\Html\Parameter(
 			$view->event->get('params'),
-			PATH_CORE . DS . 'components' . DS . 'com_events' . DS . 'events.xml'
+			Component::path('com_events') . DS . 'events.xml'
 		);
 
-
 		//added need scripts and stylesheets
 		$this->js('fileupload/jquery.fileupload', 'system');
 		$this->js('fileupload/jquery.iframe-transport', 'system');
@@ -784,14 +778,11 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 		}
 
 		//make sure registration email is valid
-		if ($registration && isset($event['email']) && $event['email'] != '') {
-			$emailArray = explode(',', $event['email']);
-			if (!filter_var_array($emailArray, FILTER_VALIDATE_EMAIL))
-			{
-				$this->setError('You must enter a valid email address for the events registration admin email.');
-				$this->event = $eventsModelEvent;
-				return $this->edit();
-			}
+		if ($registration && isset($event['email']) && $event['email'] != '' && !filter_var($event['email'], FILTER_VALIDATE_EMAIL))
+		{
+			$this->setError('You must enter a valid email address for the events registration admin email.');
+			$this->event = $eventsModelEvent;
+			return $this->edit();
 		}
 
 		//make sure registration email is valid
@@ -1023,7 +1014,7 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 	/**
 	 * Authenticate Subscription Requests
 	 *
-	 * @return  void
+	 * @return  object
 	 */
 	private function authenticateSubscriptionRequest()
 	{
@@ -1060,10 +1051,7 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 		if (!is_object($user) || $user->id == '' || $user->id == 0)
 		{
 			App::get('log')->logger('auth')->info($httpBasicUsername . ' ' . $_SERVER['REMOTE_ADDR'] . ' invalid group calendar subscription auth for ' . $this->group->get('cn'));
-			if (strpos(php_sapi_name(),'apache') !== false)
-			{
-				apache_note('auth', 'invalid');
-			}
+
 			header('HTTP/1.1 401 Unauthorized');
 			header('WWW-Authenticate: Basic realm="' . $realm . '"');
 			die(Lang::txt('You must enter a valid username and password.'));
@@ -1073,10 +1061,7 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 		if (!\Hubzero\User\Password::comparePasswords($user->passhash, $httpBasicPassword))
 		{
 			App::get('log')->logger('auth')->info($httpBasicUsername . ' ' . $_SERVER['REMOTE_ADDR'] . ' invalid group calendar subscription auth for ' . $this->group->get('cn'));
-			if (strpos(php_sapi_name(),'apache') !== false)
-			{
-				apache_note('auth', 'invalid');
-			}
+
 			header('HTTP/1.1 401 Unauthorized');
 			header('WWW-Authenticate: Basic realm="' . $realm . '"');
 			die(Lang::txt('You must enter a valid username and password.'));
@@ -1133,7 +1118,7 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 		$event->recurrence = $recurrence;
 
 		//return event details
-		echo json_encode(array('event'=> $event));
+		echo json_encode(array('event' => $event));
 		exit();
 	}
 
@@ -1392,10 +1377,7 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 			}
 
 			//send email
-			$emailArray = explode(',', $eventsEvent->email);
-			foreach ($emailArray as $emailSingle) {
-				$this->_sendEmail($emailSingle, $from, $subject, $message);
-			}
+			$this->_sendEmail($eventsEvent->email, $from, $subject, $message);
 		}
 
 		// build message to send to event registerer
@@ -1561,7 +1543,8 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 	/**
 	 * Escape string for csv output
 	 *
-	 * @return  string
+	 * @param   string  $value  Escape quotations, commas, and new lines
+	 * @return  string  Escaped $value
 	 */
 	private function escapeCsv($value)
 	{
@@ -1581,39 +1564,6 @@ class plgGroupsCalendar extends \Hubzero\Plugin\Plugin
 		}
 	}
 
-	/**
-	 * Unregister from an event
-	 *
-	 * $return  void
-	 */
-	private function unregister() 
-	{
-		Request::checkToken('get');
-
-		$db = App::get('db');
-		$event_id = Request::getVar('event_id', array(), 'get');
-		$email = Request::getVar('email', array(), 'get');
-
-		if ($this->user->authorise('manager') || $this->user->email == $email) {
-			$sql = "DELETE FROM `#__events_respondents` WHERE event_id='$event_id' AND email='$email'";
-			$db->setQuery($sql);
-			$db->query();
-			App::redirect(
-				Route::url('index.php?option=' . $this->option . '&cn=' . $this->group->cn . '&calendar_id=' . $event_id . '&active=calendar&action=details'),
-				Lang::txt('Unregistered from event'),
-				'passed'
-			);
-		}
-		else {
-
-			App::redirect(
-				Route::url('index.php?option=' . $this->option . '&cn=' . $this->group->cn . '&calendar_id=' . $event_id . '&active=calendar&action=details'),
-				Lang::txt('Incorrect email while being unregistered'),
-				'warning'
-			);
-		}
-	}
-
 	/**
 	 * View Group Calendars
 	 *
