@@ -180,17 +180,15 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			$this->group_plugin_acl = $group_plugin_acl;
 			$this->authorized = $authorized;
 
-			//group vars
-			//$this->members = $members;
-			//get the plugins params
-			$p = new \Hubzero\Plugin\Params($this->database);
-			$this->params = $p->getParams($this->group->get('gidNumber'), 'groups', $this->_name);
-
+			// Get the plugins params
+			$this->params = \Hubzero\Plugin\Params::getParams($this->group->get('gidNumber'), 'groups', $this->_name);
+			$this->params->def('allow_anonymous', 1);
+			$this->params->def('threading', 'list');
+			$this->params->def('threading_depth', 3);
 			$this->params->set('access-plugin', $group_plugin_acl);
 
 			//option and paging vars
 			$this->option = $option;
-			//$this->name = substr($option, 4, strlen($option));
 			$this->limitstart = $limitstart;
 			$this->limit = $limit;
 			$this->base = 'index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=' . $this->_name;
@@ -551,6 +549,8 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			->ordered()
 			->rows();
 
+		$categories = $this->forum->categories()->rows();
+
 		//get authorization
 		$this->_authorize('section');
 		$this->_authorize('category');
@@ -577,6 +577,7 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 				$this->setError($this->forum->getError());
 			}
 			$sections = $this->forum->sections($filters)
+				->purgeCache() // Previous query cached 'no results'
 				->ordered()
 				->rows();
 		}
@@ -610,6 +611,7 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			->set('config', $this->params)
 			->set('forum', $this->forum)
 			->set('sections', $sections)
+			->set('categories', $categories)
 			->set('edit', $edit)
 			->loadTemplate();
 	}
@@ -825,6 +827,11 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			break;
 		}
 
+		if (!in_array($filters['sort_Dir'], array('ASC', 'DESC')))
+		{
+			$filters['sort_Dir'] = 'DESC';
+		}
+
 		$section = Section::all()
 			->whereEquals('alias', $filters['section'])
 			->whereEquals('scope', $this->forum->get('scope'))
@@ -891,6 +898,8 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			'limit'      => Request::getInt('limit', 25),
 			'start'      => Request::getInt('limitstart', 0),
 			'search'     => Request::getVar('q', ''),
+			'orderBy'    => Request::getVar('orderBy', 'created'),
+			'orderDir'   => Request::getVar('orderDir', 'DESC'),
 			'scope'      => $this->forum->get('scope'),
 			'scope_id'   => $this->forum->get('scope_id'),
 			'state'      => 1,
@@ -901,6 +910,11 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			return $this->sections();
 		}
 
+		if (!in_array($filters['orderDir'], array('ASC', 'DESC')))
+		{
+			$filters['orderDir'] = 'DESC';
+		}
+
 		if (!User::isGuest())
 		{
 			$filters['access'][] = 2;
@@ -1208,8 +1222,17 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			'scope'    => $this->forum->get('scope'),
 			'scope_id' => $this->forum->get('scope_id'),
 			'state'    => Post::STATE_PUBLISHED,
-			'access'   => User::getAuthorisedViewLevels()
+			'access'   => array(1)
 		);
+		if (!User::isGuest())
+		{
+			$filters['access'][] = 2; // Registered
+			$filters['access'][] = 4; // Protected
+		}
+		if (in_array(User::get('id'), $this->members))
+		{
+			$filters['access'][] = 5; // Private
+		}
 
 		// Section
 		$section = Section::all()
@@ -1531,37 +1554,7 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			$post->set('category', $category->get('alias'));
 
 			// Figure out who should be notified about this comment (all group members for now)
-			$userIDsToEmail = array();
-
-			$memberoptions = false;
-			if (file_exists(PATH_CORE . DS . 'plugins' . DS . 'groups' . DS . 'memberoptions' . DS . 'models' . DS . 'memberoption.php'))
-			{
-				include_once(PATH_CORE . DS . 'plugins' . DS . 'groups' . DS . 'memberoptions' . DS . 'models' . DS . 'memberoption.php');
-				$memberoptions = true;
-			}
-
-			foreach ($this->members as $mbr)
-			{
-				//Look up user info
-				$user = User::getInstance($mbr);
-
-				if ($user->get('id') && $memberoptions)
-				{
-					// Find the user's group settings, do they want to get email (0 or 1)?
-					$groupMemberOption = Plugins\Groups\Memberoptions\Models\Memberoption::oneByUserAndOption(
-						$this->group->get('gidNumber'),
-						$user->get('id'),
-						'receive-forum-email'
-					);
-
-					$sendEmail = $groupMemberOption->get('optionvalue', 0);
-
-					if ($sendEmail == 1)
-					{
-						$userIDsToEmail[] = $user->get('id');
-					}
-				}
-			}
+			$userIDsToEmail = $this->_getEmailRecipientIds($category);
 
 			$allowEmailResponses = true;
 
@@ -1702,6 +1695,114 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 		);
 	}
 
+	/**
+	 * Get email recipient IDs
+	 *
+	 * @param   object  $category
+	 * @return  array
+	 */
+	protected function _getEmailRecipientIds($category)
+	{
+		$userIDsToEmail = array();
+		$memberoptions = $this->_loadMemberOptions();
+		$categorySubscriptionsEnabled = Component::params('com_groups')->get('enable_forum_email_categories', 0);
+		$users = $this->_loadExistingUsers($this->members);
+
+		foreach ($users as $user)
+		{
+			$userId = $user->get('id');
+
+			$sendEmail = $this->_shouldUserReceiveEmail($userId, $memberoptions, $categorySubscriptionsEnabled, $category);
+
+			if ($sendEmail == 1)
+			{
+				$userIDsToEmail[] = $userId;
+			}
+		}
+
+		return $userIDsToEmail;
+	}
+
+	/**
+	 * Load required model
+	 *
+	 * @return  bool
+	 */
+	protected function _loadMemberOptions()
+	{
+		$memberoptions = false;
+
+		if (file_exists(PATH_CORE . DS . 'plugins' . DS . 'groups' . DS . 'memberoptions' . DS . 'models' . DS . 'memberoption.php'))
+		{
+			include_once(PATH_CORE . DS . 'plugins' . DS . 'groups' . DS . 'memberoptions' . DS . 'models' . DS . 'memberoption.php');
+			$memberoptions = true;
+		}
+
+		return $memberoptions;
+	}
+
+	/**
+	 * Get a list of User objects from group membership
+	 *
+	 * Note: filters out blocked and unapproved accounts
+	 *
+	 * @param   array  $userIds
+	 * @return  array
+	 */
+	protected function _loadExistingUsers($userIds)
+	{
+		$users = array_map(function($userId)
+		{
+			return User::getInstance($userId);
+		}, $userIds);
+
+		$existingUsers = array_filter($users, function($user)
+		{
+			return ($user->get('id') && !$user->get('block') && $user->get('approved') > 0);
+		});
+
+		return $existingUsers;
+	}
+
+	/**
+	 * Get a list of User objects from group membership
+	 *
+	 * Note: filters out blocked and unapproved accounts
+	 *
+	 * @param   integer  $userId
+	 * @param   object   $memberoptions
+	 * @param   bool     $categorySubscriptionsEnabled
+	 * @param   object   $category
+	 * @return  array
+	 */
+	protected function _shouldUserReceiveEmail($userId, $memberoptions, $categorySubscriptionsEnabled, $category)
+	{
+		$categoryId = $category->get('id');
+
+		if ($categorySubscriptionsEnabled)
+		{
+			$usersCategory = $category->usersCategories()
+				->whereEquals('category_id', $categoryId)
+				->whereEquals('user_id', $userId)
+				->row();
+
+			$sendEmail = $usersCategory->isNew() ? 0 : 1;
+		}
+		else if ($memberoptions)
+		{
+			$groupId = $this->group->get('gidNumber');
+			$usersGroupSettings = Plugins\Groups\Memberoptions\Models\Memberoption::oneByUserAndOption(
+				$groupId,
+				$userId,
+				'receive-forum-email'
+			);
+
+			$sendEmail = $usersGroupSettings->get('optionvalue', 0);
+		}
+
+		return $sendEmail;
+	}
+
 	/**
 	 * Remove a thread
 	 *
