@@ -33,8 +33,7 @@
 // No direct access
 defined('_HZEXEC_') or die();
 
-include_once(PATH_CORE . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'type.php');
-include_once(PATH_CORE . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'resource.php');
+include_once Component::path('com_resources') . DS . 'models' . DS . 'entry.php';
 
 /**
  * Groups Plugin class for resources
@@ -44,7 +43,7 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 	/**
 	 * Affects constructor behavior. If true, language files will be loaded automatically.
 	 *
-	 * @var    boolean
+	 * @var  boolean
 	 */
 	protected $_autoloadLanguage = true;
 
@@ -187,38 +186,6 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 				$arr['html'] = '<p class="info">' . Lang::txt('GROUPS_PLUGIN_REQUIRES_MEMBER', ucfirst($active)) . '</p>';
 				return $arr;
 			}
-
-			if (file_exists(PATH_CORE . DS . 'components' . DS . 'com_search' . DS . 'models' . DS . 'hubgraph' . DS . 'client.php'))
-			{
-				require_once PATH_CORE . DS . 'components' . DS . 'com_search' . DS . 'models' . DS . 'hubgraph' . DS . 'client.php';
-
-				$hgConf = \Components\Search\Models\Hubgraph\Configuration::instance();
-
-				if ($hgConf->isOptionEnabled('com_groups'))
-				{
-					$view =$this->view('default', 'results');
-					// Pass the view some info
-					$view->option = $option;
-					$view->group  = $group;
-
-					Lang::load('com_search', PATH_CORE . DS . 'components' . DS . 'com_search' . DS . 'site');
-
-					ob_start();
-					$_GET['group'] = $group->gidNumber;
-					Request::setVar('group', $group->gidNumber);
-					define('HG_INLINE', 1);
-					require PATH_CORE . DS . 'components' . DS . 'com_search' . DS . 'site' . DS . 'controllers' . DS . 'hubgraph.php';
-					$controller = new \Components\Search\Site\Controllers\Hubgraph();
-					$controller->execute();
-					$controller->redirect();
-
-					$view->hubgraphResponse = ob_get_clean();
-
-					return array(
-						'html' => $view->loadTemplate('hubgraph')
-					);
-				}
-			}
 		}
 
 		$database = App::get('db');
@@ -288,7 +255,7 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 		$i = 0;
 		$total = 0;
 		$cats = array();
-		foreach ($rareas as $c=>$t)
+		foreach ($rareas as $c => $t)
 		{
 			$cats[$i]['category'] = $c;
 
@@ -301,7 +268,7 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 				$cats[$i]['_sub']  = array();
 				$z = 0;
 				// Loop through each sub-category
-				foreach ($t as $s=>$st)
+				foreach ($t as $s => $st)
 				{
 					// Ensure a matching array of totals exist
 					if (is_array($totals[$i]) && !empty($totals[$i]) && isset($totals[$i][$z]))
@@ -360,11 +327,10 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 					// Load neccesities for com_resources controller
 					$lang = App::get('language');
 					$lang->load('com_resources', Component::path('com_resources') . DS . 'site');
-					require_once Component::path('com_resources') . DS .'models' . DS . 'resource.php';
+
+					require_once Component::path('com_resources') . DS .'models' . DS . 'entry.php';
 					require_once Component::path('com_resources') . DS .'site' . DS . 'controllers' . DS . 'resources.php';
-					require_once Component::path('com_resources') . DS .'helpers' . DS . 'helper.php';
 					require_once Component::path('com_resources') . DS .'helpers' . DS . 'html.php';
-					require_once Component::path('com_resources') . DS .'helpers' . DS . 'tags.php';
 					require_once Component::path('com_tools') . DS . 'tables' . DS . 'tool.php';
 					require_once Component::path('com_tools') . DS . 'tables' . DS . 'version.php';
 					require_once Component::path('com_tools') . DS . 'tables' . DS . 'author.php';
@@ -447,11 +413,10 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 			foreach ($ids as $id)
 			{
 				// Disassociate the resource from the group and unpublish it
-				$rr = new \Components\Resources\Tables\Resource($database);
-				$rr->load($id->id);
-				$rr->group_owner = '';
-				$rr->published = 0;
-				$rr->store();
+				$rr = Components\Resources\Models\Entry::oneOrFail($id->id);
+				$rr->set('group_owner', '');
+				$rr->set('published', Components\Resources\Models\Entry::STATE_UNPUBLISHED);
+				$rr->save();
 
 				// Add the page ID to the log
 				$log .= $id->id . ' ' . "\n";
@@ -483,7 +448,7 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 	 * @param      string $gid Group alias
 	 * @return     array
 	 */
-	private function getResourceIDs($gid=NULL)
+	private function getResourceIDs($gid=null)
 	{
 		if (!$gid)
 		{
@@ -491,7 +456,7 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 		}
 		$database = App::get('db');
 
-		$rr = new \Components\Resources\Tables\Resource($database);
+		$rr = \Components\Resources\Models\Entry::blank();
 
 		$database->setQuery("SELECT id FROM ".$rr->getTableName()." AS r WHERE r.group_owner=".$database->quote($gid));
 		return $database->loadObjectList();
@@ -500,7 +465,7 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 	/**
 	 * Get a list of resource categories (types)
 	 *
-	 * @return     array
+	 * @return  array
 	 */
 	public function getResourcesAreas()
 	{
@@ -510,26 +475,22 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 			return $areas;
 		}
 
-		$categories = $this->_cats;
-		if (!is_array($categories))
+		if (!is_array($this->_cats))
 		{
 			// Get categories
-			$database = App::get('db');
-			$rt = new \Components\Resources\Tables\Type($database);
-			$categories = $rt->getMajorTypes();
-			$this->_cats = $categories;
+			$this->_cats = Components\Resources\Models\Type::getMajorTypes();
 		}
+		$categories = $this->_cats;
 
 		// Normalize the category names
 		// e.g., "Oneline Presentations" -> "onlinepresentations"
 		$cats = array();
-		for ($i = 0; $i < count($categories); $i++)
+		foreach ($categories as $category)
 		{
-			$normalized = preg_replace("/[^a-zA-Z0-9]/", '', $categories[$i]->type);
+			$normalized = preg_replace("/[^a-zA-Z0-9]/", '', $category->type);
 			$normalized = strtolower($normalized);
 
-			//$categories[$i]->title = $normalized;
-			$cats[$normalized] = $categories[$i]->type;
+			$cats[$normalized] = $category->type;
 		}
 
 		$areas = array(
@@ -542,14 +503,14 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 	/**
 	 * Retrieve records for items associated with this group
 	 *
-	 * @param      object  $group      Group that owns the records
-	 * @param      unknown $authorized Authorization level
-	 * @param      mixed   $limit      SQL record limit
-	 * @param      integer $limitstart SQL record limit start
-	 * @param      string  $sort       The field to sort records by
-	 * @param      string  $access     Access level
-	 * @param      mixed   $areas      An array or string of areas that should retrieve records
-	 * @return     mixed Returns integer when counting records, array when retrieving records
+	 * @param   object   $group       Group that owns the records
+	 * @param   bool     $authorized  Authorization level
+	 * @param   mixed    $limit       SQL record limit
+	 * @param   integer  $limitstart  SQL record limit start
+	 * @param   string   $sort        The field to sort records by
+	 * @param   string   $access      Access level
+	 * @param   mixed    $areas       An array or string of areas that should retrieve records
+	 * @return  mixed    Returns integer when counting records, array when retrieving records
 	 */
 	public function getResources($group, $authorized, $limit=0, $limitstart=0, $sort='date', $access='all', $areas=null)
 	{
@@ -571,38 +532,32 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 			return array();
 		}
 
-		$database = App::get('db');
-
-		// Instantiate some needed objects
-		$rr = new \Components\Resources\Tables\Resource($database);
-
 		// Build query
 		$filters = array();
-		$filters['now'] = \Date::toSql();
-		$filters['sortby'] = $sort;
+		$filters['now'] = Date::toSql();
+		$filters['sortby'] = ($sort == 'date' ? 'created' : $sort);
 		$filters['group'] = $group->get('cn');
 		$filters['access'] = $access;
 		$filters['authorized'] = $authorized;
-		$filters['state'] = array(1);
+		$filters['published'] = array(1);
 
 		// Get categories
 		$categories = $this->_cats;
 		if (!is_array($categories))
 		{
-			$rt = new \Components\Resources\Tables\Type($database);
-			$categories = $rt->getMajorTypes();
+			$categories = Components\Resources\Models\Type::getMajorTypes();
 		}
 
 		// Normalize the category names
 		// e.g., "Oneline Presentations" -> "onlinepresentations"
 		$cats = array();
-		for ($i = 0; $i < count($categories); $i++)
+		foreach ($categories as $category)
 		{
-			$normalized = preg_replace("/[^a-zA-Z0-9]/", '', $categories[$i]->type);
+			$normalized = preg_replace("/[^a-zA-Z0-9]/", '', $category->type);
 			$normalized = strtolower($normalized);
 
 			$cats[$normalized] = array();
-			$cats[$normalized]['id'] = $categories[$i]->id;
+			$cats[$normalized]['id'] = $category->id;
 		}
 
 		if ($limit)
@@ -633,10 +588,15 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 			}
 
 			// Get results
-			$database->setQuery($rr->buildPluginQuery($filters));
-			$rows = $database->loadObjectList();
+			$rows = Components\Resources\Models\Entry::allWithFilters($filters)
+				->order($filters['sortby'], 'asc')
+				->limit($limit)
+				->start($limitstart)
+				->rows();
 
 			// Did we get any results?
+			$results = array();
+
 			if ($rows)
 			{
 				// Loop through the results and set each item's HREF
@@ -646,24 +606,21 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 					{
 						if ($row->alias)
 						{
-							$rows[$key]->href = Route::url('index.php?option=com_groups&cn=' . $this->group->cn . '&active=resources&alias=' . $row->alias);
+							$href = Route::url('index.php?option=com_groups&cn=' . $this->group->cn . '&active=resources&alias=' . $row->alias);
 						}
 						else
 						{
-							$rows[$key]->href = Route::url('index.php?option=com_groups&cn=' . $this->group->cn . '&active=resources&id=' . $row->id);
+							$href = Route::url('index.php?option=com_groups&cn=' . $this->group->cn . '&active=resources&id=' . $row->id);
 						}
 					}
 					else
 					{
-						if ($row->alias)
-						{
-							$rows[$key]->href = Route::url('index.php?option=com_resources&alias=' . $row->alias);
-						}
-						else
-						{
-							$rows[$key]->href = Route::url('index.php?option=com_resources&id=' . $row->id);
-						}
+						$href = Route::url($row->link());
 					}
+
+					$row->set('href', $href);
+
+					$results[] = $row;
 				}
 			}
 
@@ -677,19 +634,18 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 			// Get a count
 			$counts = array();
 			$ares = $this->getResourcesAreas();
-			foreach ($ares as $area=>$val)
+			foreach ($ares as $area => $val)
 			{
 				if (is_array($val))
 				{
 					$i = 0;
-					foreach ($val as $a=>$t)
+					foreach ($val as $a => $t)
 					{
 						if ($limitstart == -1)
 						{
 							if ($i == 0)
 							{
-								$database->setQuery($rr->buildPluginQuery($filters));
-								$counts[] = $database->loadResult();
+								$counts[] = self::allWithFilters($filters)->total();
 							}
 							else
 							{
@@ -701,8 +657,7 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 							$filters['type'] = $cats[$a]['id'];
 
 							// Execute a count query for each area/category
-							$database->setQuery($rr->buildPluginQuery($filters));
-							$counts[] = $database->loadResult();
+							$counts[] = self::allWithFilters($filters)->total();
 						}
 						$i++;
 					}
@@ -714,5 +669,143 @@ class plgGroupsResources extends \Hubzero\Plugin\Plugin
 			return $counts;
 		}
 	}
-}
 
+	/**
+	 * Include needed libraries and push scripts and CSS to the document
+	 *
+	 * @param   array  $filters
+	 * @return  object
+	 */
+	public static function allWithFilters($filters = array())
+	{
+		$query = \Components\Resources\Models\Entry::all();
+
+		$r = $query->getTableName();
+		$a = \Components\Resources\Models\Author::blank()->getTableName();
+
+		$query
+			->select($r . '.*');
+
+		if (isset($filters['standalone']))
+		{
+			$query->whereEquals($r . '.standalone', $filters['standalone']);
+		}
+
+		if (isset($filters['published']))
+		{
+			$query->whereIn($r . '.published', (array) $filters['published']);
+		}
+
+		if (isset($filters['group']))
+		{
+			$query->whereEquals($r . '.group_owner', (string) $filters['group']);
+		}
+
+		if (isset($filters['type']))
+		{
+			if (!is_numeric($filters['type']))
+			{
+				$filters['type'] = Type::oneByAlias($filters['type'])->get('id');
+			}
+			$query->whereEquals($r . '.type', $filters['type']);
+		}
+
+		if (isset($filters['tag']) && $filters['tag'])
+		{
+			$to = \Components\Tags\Models\Objct::blank()->getTableName();
+			$tg = \Components\Tags\Models\Tag::blank()->getTableName();
+
+			$cloud = new \Components\Resources\Helpers\Tags();
+			$tags = $cloud->parse($filters['tag']);
+
+			$query->join($to, $to . '.objectid', $r . '.id');
+			$query->join($tg, $tg . '.id', $to . '.tagid', 'inner');
+			$query->whereEquals($to . '.tbl', 'resources');
+			$query->whereIn($tg . '.tag', $tags);
+		}
+
+		if (isset($filters['search']))
+		{
+			$query->whereLike($r . '.title', $filters['search'], 1)
+				->orWhereLike($r . '.fulltxt', $filters['search'], 1)
+				->resetDepth();
+		}
+
+		if (isset($filters['created_by']))
+		{
+			$query->whereEquals($r . '.created_by', $filters['created_by']);
+		}
+
+		if (isset($filters['author']))
+		{
+			$query
+				->join($a, $a . '.subid', $r . '.id', 'left')
+				->whereEquals($a . '.subtable', 'resources')
+				->whereEquals($a . '.authorid', $filters['author']);
+
+			if (isset($filters['notauthorrole']))
+			{
+				$query->where($a . '.role', '!=', $filters['notauthorrole']);
+			}
+		}
+
+		if (isset($filters['access']) && !empty($filters['access']))
+		{
+			if (!is_array($filters['access']) && !is_numeric($filters['access']))
+			{
+				switch ($filters['access'])
+				{
+					case 'public':
+						$filters['access'] = 0;
+						break;
+					case 'protected':
+						$filters['access'] = 3;
+						break;
+					case 'private':
+						$filters['access'] = 4;
+						break;
+					case 'all':
+					default:
+						$filters['access'] = array(0, 1, 2, 3, 4);
+						break;
+				}
+			}
+
+			if (isset($filters['usergroups']) && !empty($filters['usergroups']))
+			{
+				$query->whereIn($r . '.access', (array) $filters['access'], 1)
+					->orWhereIn($r . '.group_owner', (array) $filters['usergroups'], 1)
+					->resetDepth();
+			}
+			else
+			{
+				$query->whereIn($r . '.access', (array) $filters['access']);
+			}
+		}
+		elseif (isset($filters['usergroups']) && !empty($filters['usergroups']))
+		{
+			$query->whereIn($r . '.group_owner', (array) $filters['usergroups']);
+		}
+
+		if (isset($filters['now']))
+		{
+			$query->whereEquals($r . '.publish_up', '0000-00-00 00:00:00', 1)
+				->orWhere($r . '.publish_up', '<=', $filters['now'], 1)
+				->resetDepth()
+				->whereEquals($r . '.publish_down', '0000-00-00 00:00:00', 1)
+				->orWhere($r . '.publish_down', '>=', $filters['now'], 1)
+				->resetDepth();
+		}
+
+		if (isset($filters['startdate']) && $filters['startdate'])
+		{
+			$query->where($r . '.publish_up', '>', $filters['startdate']);
+		}
+		if (isset($filters['enddate']) && $filters['enddate'])
+		{
+			$query->where($r . '.publish_up', '<', $filters['enddate']);
+		}
+
+		return $query;
+	}
+}
