@@ -62,6 +62,8 @@ class plgMembersMessages extends \Hubzero\Plugin\Plugin
 		{
 			$areas['messages'] = Lang::txt('PLG_MEMBERS_MESSAGES');
 			$areas['icon'] = '2709';
+			$areas['icon-class'] = 'icon-envelope';
+			$areas['menu'] = $this->params->get('display_tab', 1);
 		}
 
 		return $areas;
@@ -144,12 +146,14 @@ class plgMembersMessages extends \Hubzero\Plugin\Plugin
 				case 'delete':
 					$body = $this->delete($database, $option, $member);
 					break;
+
 				case 'send':
 					$body = $this->send($database, $option, $member);
 					break;
 				case 'new':
 					$body = $this->create($database, $option, $member);
 					break;
+
 				case 'view':
 					$body = $this->message($database, $option, $member, $mid);
 					break;
@@ -869,17 +873,8 @@ class plgMembersMessages extends \Hubzero\Plugin\Plugin
 		// Check for request forgeries
 		Request::checkToken();
 
-		$filters = array(
-			'limit' => Request::getState(
-				$option . '.plugin.messages.limit',
-				'limit',
-				Config::get('list_limit'),
-				'int'
-			)
-		);
-
 		// Incoming
-		//$override = Request::getInt('override',0);
+		//$override = Request::getInt('override', 0);
 		$settings = Request::getVar('settings', array());
 		$ids = Request::getVar('ids', array());
 
@@ -969,7 +964,7 @@ class plgMembersMessages extends \Hubzero\Plugin\Plugin
 		// Push through to the settings view
 		$this->addPluginMessage(Lang::txt('You have successfully saved your message settings.'), 'passed');
 
-		return App::redirect(Route::url($member->link() . '&active=messages&task=inbox&limit=' . $filters['limit'] . '&limitstart=0', false));
+		return App::redirect(Route::url($member->link() . '&active=messages&action=settings'));
 	}
 
 	/**
