@@ -33,7 +33,7 @@
 // No direct access
 defined('_HZEXEC_') or die();
 
-include_once PATH_CORE . DS . 'components' . DS . 'com_publications' . DS . 'models' . DS . 'publication.php';
+include_once \Component::path('com_publications') . DS . 'models' . DS . 'publication.php';
 
 /**
  * Project publications
@@ -1056,7 +1056,7 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 		// Record activity
 		if ($this->get('_activity'))
 		{
-			$pubTitle = \Hubzero\Utility\String::truncate($pub->title, 100);
+			$pubTitle = \Hubzero\Utility\Str::truncate($pub->title, 100);
 			$aid = $this->model->recordActivity(
 				$this->get('_activity'),
 				$pub->id,
@@ -1557,7 +1557,10 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 	/**
 	 *  Append breadcrumbs
 	 *
-	 * @return   void
+	 * @param   string  $title
+	 * @param   string  $url
+	 * @param   string  $version
+	 * @return  void
 	 */
 	protected function _appendBreadcrumbs($title, $url, $version = 'default')
 	{
@@ -1657,32 +1660,31 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 			else
 			{
 				// Include support scripts
-				include_once PATH_CORE . DS . 'components' . DS . 'com_support' . DS . 'tables' . DS . 'ticket.php';
-				include_once PATH_CORE . DS . 'components' . DS . 'com_support' . DS . 'tables' . DS . 'comment.php';
+				include_once PATH_CORE . DS . 'components' . DS . 'com_support' . DS . 'models' . DS . 'ticket.php';
 
 				// Load the support config
 				$sparams = Component::params('com_support');
 
-				$row = new \Components\Support\Tables\Ticket($this->_database);
-				$row->created = Date::toSql();
-				$row->login   = User::get('username');
-				$row->email   = User::get('email');
-				$row->name    = User::get('name');
-				$row->summary = Lang::txt('PLG_PROJECTS_PUBLICATIONS_LICENSE_SUGGESTION_NEW');
+				$row = \Components\Support\Models\Ticket::blank();
+				$row->set('created', Date::toSql());
+				$row->set('login', User::get('username'));
+				$row->set('email', User::get('email'));
+				$row->set('name', User::get('name'));
+				$row->set('summary', Lang::txt('PLG_PROJECTS_PUBLICATIONS_LICENSE_SUGGESTION_NEW'));
 
 				$report  = Lang::txt('PLG_PROJECTS_PUBLICATIONS_LICENSE_TITLE') . ': ' . $l_title ."\r\n";
 				$report .= Lang::txt('PLG_PROJECTS_PUBLICATIONS_LICENSE_URL') . ': ' . $l_url . "\r\n";
 				$report .= Lang::txt('PLG_PROJECTS_PUBLICATIONS_LICENSE_COMMENTS') . ': ' . $l_text ."\r\n";
-				$row->report   = $report;
-				$row->referrer = Request::getVar('HTTP_REFERER', null, 'server');
-				$row->type     = 0;
-				$row->severity = 'normal';
+				$row->set('report', $report);
+				$row->set('referrer', Request::getVar('HTTP_REFERER', null, 'server'));
+				$row->set('type', 0);
+				$row->set('severity', 'normal');
 
 				$admingroup = $this->model->config()->get('admingroup', '');
 				$group = \Hubzero\User\Group::getInstance($admingroup);
-				$row->group = $group ? $group->get('cn') : '';
+				$row->set('group_id', $group ? $group->get('gidNumber') : '');
 
-				if (!$row->store())
+				if (!$row->save())
 				{
 					$this->setError($row->getError());
 				}
@@ -1881,7 +1883,7 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 					$this->set('_msg', Lang::txt('PLG_PROJECTS_PUBLICATIONS_PUBLICATION_NEW_VERSION_STARTED'));
 
 					// Set activity message
-					$pubTitle = \Hubzero\Utility\String::truncate($new->title, 100);
+					$pubTitle = \Hubzero\Utility\Str::truncate($new->title, 100);
 					$action   = Lang::txt('PLG_PROJECTS_PUBLICATIONS_PUBLICATION_ACTIVITY_STARTED_VERSION') . ' ' . $new->version_label . ' ';
 					$action .=  Lang::txt('PLG_PROJECTS_PUBLICATIONS_OF_PUBLICATION') . ' "' . $pubTitle . '"';
 					$this->set('_activity', $action);
@@ -2186,6 +2188,11 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 			}
 		}
 
+		if ($state == 1 && (!$pub->version->get('accepted') || $pub->version->get('accepted') == '0000-00-00 00:00:00'))
+		{
+			$pub->version->set('accepted', Date::toSql());
+		}
+
 		// Save state
 		$pub->version->set('state', $state);
 		$pub->version->set('main', $main);
@@ -2272,7 +2279,9 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 	/**
 	 * On after change status
 	 *
-	 * @return     string
+	 * @param   object   $pub
+	 * @param   integer  $originalStatus
+	 * @return  string
 	 */
 	public function onAfterChangeState($pub, $originalStatus = 3)
 	{
@@ -2316,7 +2325,7 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 		}
 		$this->_msg .= ' <a href="' . Route::url($pub->link('version')) . '">' . Lang::txt('PLG_PROJECTS_PUBLICATIONS_PUBLICATION_VIEWIT') . '</a>';
 
-		$pubtitle = \Hubzero\Utility\String::truncate($pub->version->get('title'), 100);
+		$pubtitle = \Hubzero\Utility\Str::truncate($pub->version->get('title'), 100);
 		$action  .= ' ' . $pub->version->get('version_label') . ' ';
 		$action  .=  Lang::txt('PLG_PROJECTS_PUBLICATIONS_OF_PUBLICATION') . ' "' . html_entity_decode($pubtitle) . '"';
 		$action   = htmlentities($action, ENT_QUOTES, "UTF-8");
@@ -2369,7 +2378,8 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 			}
 
 			// Notify curators by email
-			$curatorMessage = ($pub->version->get('state') == 5) ? $message . "\n" . "\n" . Lang::txt('PLG_PROJECTS_PUBLICATIONS_EMAIL_CURATORS_REVIEW') . ' ' . rtrim(Request::base(), DS) . DS . 'publications/curation' : $message;
+			$curationPubLink = rtrim(Request::base(), DS) . DS . Route::url($pub->link('curate'));
+			$curatorMessage = ($pub->version->get('state') == 5) ? $message . "\n" . "\n" . Lang::txt('PLG_PROJECTS_PUBLICATIONS_EMAIL_CURATORS_REVIEW') . ' ' . $curationPubLink : $message;
 
 			$curatorgroups = array($pub->masterType()->curatorgroup);
 			if ($this->_pubconfig->get('curatorgroup', ''))
@@ -2433,6 +2443,7 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 	/**
 	 * Parse embargo date
 	 *
+	 * @param   string  $pubdate
 	 * @return  string
 	 */
 	private function _parseDate($pubdate)
@@ -2527,7 +2538,7 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 		{
 			if (!$this->getError())
 			{
-				$pubtitle = \Hubzero\Utility\String::truncate($pub->version->get('title'), 100);
+				$pubtitle = \Hubzero\Utility\Str::truncate($pub->version->get('title'), 100);
 
 				if ($pub->version->get('state') == 1)
 				{
@@ -2584,10 +2595,10 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 					$pScreenshot->deleteScreenshots($vid);
 
 					// Build publication path
-					$path =  PATH_APP . DS . trim($this->_pubconfig->get('webpath'), DS) . DS . \Hubzero\Utility\String::pad($pid);
+					$path =  PATH_APP . DS . trim($this->_pubconfig->get('webpath'), DS) . DS . \Hubzero\Utility\Str::pad($pid);
 
 					// Build version path
-					$vPath = $path . DS . \Hubzero\Utility\String::pad($vid);
+					$vPath = $path . DS . \Hubzero\Utility\Str::pad($vid);
 
 					// Delete all version files
 					if (is_dir($vPath))
@@ -2616,8 +2627,28 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 						$pub->publication->deleteExistence($pid);
 
 						// Delete related publishing activity from feed
-						$objAA = $this->model->table('Activity');
-						$objAA->deleteActivityByReference($this->model->get('id'), $pid, 'publication');
+						$activities = Hubzero\Activity\Log::all()
+							->whereEquals('scope', 'publication')
+							->whereEquals('scope_id', $pid)
+							->rows()
+							->toArray();
+
+						$logs = array();
+						foreach ($activities as $activity)
+						{
+							$logs[] = $activity['id'];
+						}
+
+						$past = Hubzero\Activity\Recipient::all()
+							->whereIn('log_id', $logs)
+							->whereEquals('state', 1)
+							->rows();
+
+						foreach ($past as $p)
+						{
+							$p->set('state', 0);
+							$p->save();
+						}
 					}
 
 					// Add activity
@@ -2742,6 +2773,28 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 	 */
 	public function contribute()
 	{
+		$choices = array();
+
+		if ($this->_pubconfig->get('contribute', 0))
+		{
+			$mt = new \Components\Publications\Tables\MasterType($this->_database);
+			$choice = $this->_pubconfig->get('contribute_default', 'files');
+
+			if ($choice != '*')
+			{
+				$type = $mt->getType($choice);
+
+				if ($type)
+				{
+					$choices[] = $type;
+				}
+			}
+			else
+			{
+				$choices = $mt->getTypes('*', 1, 0, 'ordering');
+			}
+		}
+
 		$view = new \Hubzero\Plugin\View(
 			array(
 				'folder'  => 'projects',
@@ -2757,6 +2810,7 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 		// Instantiate a publication object
 		$view->pub     = new \Components\Publications\Models\Publication();
 		$view->project = $this->model;
+		$view->choices = $choices;
 
 		return $view->loadTemplate();
 	}
@@ -2772,7 +2826,7 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 		$mconfig = Component::params('com_members');
 
 		// Build upload path
-		$dir  = \Hubzero\Utility\String::pad($this->_uid);
+		$dir  = \Hubzero\Utility\Str::pad($this->_uid);
 		$path = DS . trim($mconfig->get('webpath', '/site/members'), DS) . DS . $dir . DS . 'files';
 
 		if (!is_dir(PATH_APP . $path))
@@ -2910,7 +2964,9 @@ class plgProjectsPublications extends \Hubzero\Plugin\Plugin
 	/**
 	 * Serve publication-related file (via public link)
 	 *
-	 * @param   int   $projectid
+	 * @param   string   $type
+	 * @param   integer  $projectid
+	 * @param   string   $query
 	 * @return  void
 	 */
 	public function serve($type = '', $projectid = 0, $query = '')
